@@ -12,7 +12,7 @@
 #define _GNU_SOURCE
 #include <search.h>
 #include <iconv.h>
-#include "list.h"
+#include "util.h"
 
 #define COMP "cmsfs-fuse: "
 extern struct cmsfs cmsfs;
@@ -99,7 +99,7 @@ struct cmsfs {
 
 struct filetype {
 	char		name[MAX_TYPE_LEN];
-	struct list	list;
+	struct util_list_node	list;
 };
 
 #define NULL_BLOCK		0
@@ -112,7 +112,7 @@ struct filetype {
 #define BYTES_PER_BLOCK		(cmsfs.amap_bytes_per_block)
 
 extern int get_device_info(struct cmsfs *cmsfs);
-extern int scan_conf_file(struct list *list);
+extern int scan_conf_file(struct util_list *list);
 extern int is_edf_char(int c);
 
 #ifndef _CMSFS_FSCK
