@@ -1,33 +1,14 @@
 /*
- * Copyright IBM Corp 2007, 2010
- * Author: Hans-Joachim Picht <hans@linux.vnet.ibm.com>
+ * cpuplugd - Linux for System z Hotplug Daemon
  *
- * Linux for System z Hotplug Daemon
+ * Command line parsing
  *
- * This file is used to parse the command line arguments
- *
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 2 of the License, or (at your option)
- * any later version.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Copyright IBM Corp 2007, 2011
+ * Author(s): Gerald Schaefer <gerald.schaefer@de.ibm.com>
+ *            Hans-Joachim Picht <hans@linux.vnet.ibm.com>
  */
 
 #include <getopt.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <errno.h>
-#include <string.h>
-#include <fcntl.h>
-#include <sys/stat.h>
-#include <signal.h>
-#include <syslog.h>
-#include <limits.h>
 #include "cpuplugd.h"
 
 void print_usage(int is_error, char program_name[]);
@@ -68,14 +49,15 @@ void parse_options(int argc, char **argv)
 			break;
 		case 'c':
 			/*
-			 * this prevents -cbla and enforces the
+			 * This prevents -cbla and enforces the
 			 * user to specify -c bla
 			 */
 			if (strcmp(argv[optind-1], optarg) == 0) {
 				configfile = optarg;
 				config_file_specified = 1;
 			} else {
-				cpuplugd_error("Unrecognized option: %s\n", optarg);
+				cpuplugd_error("Unrecognized option: %s\n",
+					       optarg);
 				exit(1);
 			}
 			break;
@@ -86,8 +68,7 @@ void parse_options(int argc, char **argv)
 			debug = 1;
 			break;
 		case 0:
-			/* all parameter that do not
-			   appear in the optstring */
+			/* all parameter that do not appear in the optstring */
 			opt = (struct option *)&(long_options[index]);
 			printf("'%s' was specified.",
 			       opt->name);
@@ -101,8 +82,10 @@ void parse_options(int argc, char **argv)
 			exit(1);
 			break;
 		case -1:
-			/* we also run in this case if no argument was s
-			 * pecified */
+			/*
+			 * We also run in this case if no argument was
+			 * specified
+			 */
 			break;
 		default:
 			print_usage(0, argv[0]);
