@@ -16,6 +16,7 @@
 #include "dasdfmt.h"
 #include "vtoc.h"
 #include "util_proc.h"
+#include "dasd_sys.h"
 
 /* Full tool name */
 static const char tool_name[] = "dasdfmt: zSeries DASD format program";
@@ -256,6 +257,12 @@ static void check_disk(dasdfmt_info_t *info)
 			    "%s: Unsupported disk type\n%s is not an "
 			    "ECKD disk!\n", prog_name, info->devname);
 	}
+
+	if (dasd_sys_raw_track_access(info->devname)) {
+		ERRMSG_EXIT(EXIT_FAILURE,
+			    "%s: Device '%s' is in raw-track access mode\n",
+			    prog_name, info->devname);
+	}
 }
 
 
