@@ -16,6 +16,7 @@
 #include "zt_common.h"
 #include "vtoc.h"
 #include "fdasd.h"
+#include "dasd_sys.h"
 
 /* global variables */
 struct hd_geometry geo;
@@ -329,6 +330,8 @@ fdasd_partition_type (char *str)
 		strcpy(str, "Linux raid");
 	else if (strncmp("LVM   ", str, 6) == 0)
 		strcpy(str, "Linux lvm");
+	else if (strncmp("GPFS  ", str, 6) == 0)
+		strcpy(str, "GPFS NSD");
 	else
 		strcpy(str, "unknown");
 
@@ -706,6 +709,8 @@ fdasd_parse_conffile(fdasd_anchor_t *anc, struct fdasd_options *options)
 			anc->confdata[i].type = PARTITION_RAID;
 		else if (strstr(token[2], "LVM") != NULL)
 			anc->confdata[i].type = PARTITION_LVM;
+		else if (strstr(token[2], "GPFS") != NULL)
+			anc->confdata[i].type = PARTITION_GPFS;
 		else {
 			snprintf(err_str, ERROR_STRING_SIZE,
 				 "invalid partition type in config file %s\n",
@@ -845,6 +850,12 @@ fdasd_verify_device (fdasd_anchor_t *anc, char *name)
 		fdasd_error(anc, device_verification_failed, err_str);
 	}
 
+	if (dasd_sys_raw_track_access(name)) {
+		snprintf(err_str, ERROR_STRING_SIZE,
+			 "Device '%s' is in raw-track access mode\n", name);
+		fdasd_error(anc, device_verification_failed, err_str);
+	}
+
 	if (anc->verbose)
 		printf("Verification successful for '%s' (%d/%d)\n", name,
 		       (unsigned short) major(dst.st_rdev),
@@ -1200,6 +1211,8 @@ fdasd_write_vtoc_labels (fdasd_anchor_t *anc)
 				part_info->type = PARTITION_RAID;
 			else if (strstr(ch, "LVM") != NULL)
 				part_info->type = PARTITION_LVM;
+			else if (strstr(ch, "GPFS") != NULL)
+				part_info->type = PARTITION_GPFS;
 			else
 				part_info->type = PARTITION_NATIVE;
 
@@ -1238,6 +1251,9 @@ fdasd_write_vtoc_labels (fdasd_anchor_t *anc)
 			case PARTITION_LVM:
 				strncpy(c1, ".LVM", 4);
 				break;
+			case PARTITION_GPFS:
+				strncpy(c1, ".GPFS", 5);
+				break;
 			}
 		}
 		vtoc_ebcdic_enc(ch, ch, 44);
@@ -1522,9 +1538,10 @@ fdasd_change_part_type (fdasd_anchor_t *anc)
 	printf("   1  Linux native\n" \
 	       "   2  Linux swap\n" \
 	       "   3  Linux raid\n" \
-	       "   4  Linux lvm\n\n");
+	       "   4  Linux lvm\n" \
+	       "   5  GPFS NSD\n\n");
 	part_type = 0;
-	while ((part_type < 1) || (part_type > 4)) {
+	while ((part_type < 1) || (part_type > 5)) {
         	while (!isdigit(part_type =
 				read_char("new partition type: ")));
         	part_type -= 48;
@@ -1543,6 +1560,9 @@ fdasd_change_part_type (fdasd_anchor_t *anc)
 	case PARTITION_LVM:
 		strncpy(str, "LVM   ", 6);
 		break;
+	case PARTITION_GPFS:
+		strncpy(str, "GPFS  ", 6);
+		break;
 
 	default:
                 printf("'%d' is not supported!\n", part_type);
@@ -2319,6 +2339,12 @@ fdasd_read_int (unsigned long low, unsigned long dflt, unsigned long high,
 				trk /= anc->blksize;
 				trk /= geo.sectors;
 				break;
+			case 'g':
+			case 'G':
+				trk *= (1024*1024*1024);
+				trk /= anc->blksize;
+				trk /= geo.sectors;
+				break;
 			case 0x0a:
 				break;
 			default: 
@@ -2451,7 +2477,7 @@ fdasd_get_partition_data (fdasd_anchor_t *anc, extent_t *part_extent,
 	if (start == limit)
 	        stop = start;
 	else {
-	        sprintf(mesg, "Last track or +size[c|k|M]");
+		sprintf(mesg, "Last track or +size[c|k|m|g]");
 		stop = fdasd_read_int(start, limit, limit, upper, mesg, anc);
 	}
 
@@ -2838,6 +2864,8 @@ fdasd_auto_partition_conffile(fdasd_anchor_t *anc)
 			strncpy(type, ".RAID", 5);
 		else if (part_info->type == PARTITION_LVM)
 			strncpy(type, ".LVM", 4);
+		else if (part_info->type == PARTITION_GPFS)
+			strncpy(type, ".GPFS", 5);
 		else
 			strncpy(type, ".NATIVE", 7);
 		vtoc_ebcdic_enc(part_info->f1->DS1DSNAM,
