@@ -16,6 +16,7 @@
 #include "helper.h"
 #include "dg_debugfs.h"
 
+#define MTID_MASK	0x1f
 #define LPAR_NAME_LEN	8
 #define TMP_SIZE	64
 #define LPAR_PHYS_FLG	0x80
@@ -44,7 +45,9 @@ struct l_x_sys_hdr {
 	u8	rcpus;
 	u8	reserved2[5];
 	char	sys_name[LPAR_NAME_LEN];
-	u8	reserved3[80];
+	u8	reserved3[33];
+	u8	mtid;
+	u8	reserved4[46];
 } __attribute__ ((packed));
 
 static inline void l_sys_hdr__sys_name(struct l_x_sys_hdr *hdr, char *name)
@@ -65,9 +68,16 @@ struct l_x_cpu_info {
 	u8	reserved3[6];
 	u8	reserved4[2];
 	u64	online_time;
-	u8	reserved5[56];
+	u8	reserved5[24];
+	u64	mt_idle_time;
+	u8	reserved6[24];
 } __attribute__ ((packed));
 
+static int l_thread_cnt(struct l_x_sys_hdr *hdr)
+{
+	return (hdr->mtid & MTID_MASK) + 1;
+}
+
 static void l_idx2name(int index, char *name)
 {
 	switch (index) {
@@ -100,9 +110,15 @@ struct l_x_phys_cpu {
 /*
  * Fill CPU with data
  */
-static void l_sd_cpu_fill(struct sd_cpu *cpu, struct l_x_cpu_info *cpu_info)
+static void l_sd_cpu_fill(struct sd_cpu *cpu, struct l_x_cpu_info *cpu_info,
+			  int threads)
 {
 	sd_cpu_cpu_time_us_set(cpu, cpu_info->lp_time);
+	if (threads > 1)
+		sd_cpu_thread_time_us_set(cpu,
+			cpu_info->lp_time * threads - cpu_info->mt_idle_time);
+	else
+		sd_cpu_thread_time_us_set(cpu, cpu_info->lp_time);
 	sd_cpu_mgm_time_us_set(cpu, G0(cpu_info->acc_time - cpu_info->lp_time));
 	sd_cpu_online_time_us_set(cpu, cpu_info->online_time);
 	sd_cpu_state_set(cpu, SD_CPU_STATE_UNKNOWN);
@@ -131,7 +147,7 @@ static void *l_sd_sys_fill(struct sd_sys *lpar, struct l_x_sys_hdr *sys_hdr)
 			cpu = sd_cpu_new(lpar, cpu_id, cpu_type, 1);
 		}
 
-		l_sd_cpu_fill(cpu, cpu_info);
+		l_sd_cpu_fill(cpu, cpu_info, lpar->threads_per_core);
 
 		sd_cpu_commit(cpu);
 		cpu_info++;
@@ -226,7 +242,6 @@ static void l_sd_sys_root_fill(struct sd_sys *sys)
 	struct l_x_info_blk_hdr *time_hdr;
 	struct l_debugfs_d204_hdr *hdr;
 	struct l_x_sys_hdr *sys_hdr;
-	static int first = 1;
 	struct sd_sys *lpar;
 	char lpar_id[10];
 	int i;
@@ -250,14 +265,13 @@ static void l_sd_sys_root_fill(struct sd_sys *sys)
 		lpar = sd_sys_get(sys, lpar_id);
 		if (!lpar)
 			lpar = sd_sys_new(sys, lpar_id);
+		lpar->threads_per_core = l_thread_cnt(sys_hdr);
 		sys_hdr = l_sd_sys_fill(lpar, sys_hdr);
 		sd_sys_commit(lpar);
 	}
 
-	if (first && (time_hdr->flags & LPAR_PHYS_FLG)) {
+	if (time_hdr->flags & LPAR_PHYS_FLG)
 		l_sd_sys_root_cpu_phys_fill(sys, (void *) sys_hdr);
-		first = 0;
-	}
 	ht_free(hdr);
 	sd_sys_commit(sys);
 }
@@ -278,10 +292,13 @@ static void l_sd_update(void)
  * Supported system items
  */
 static struct sd_sys_item *l_sys_item_vec[] = {
-	&sd_sys_item_cpu_cnt,
-	&sd_sys_item_cpu_diff,
+	&sd_sys_item_core_cnt,
+	&sd_sys_item_thread_cnt,
+	&sd_sys_item_core_diff,
+	&sd_sys_item_thread_diff,
 	&sd_sys_item_mgm_diff,
-	&sd_sys_item_cpu,
+	&sd_sys_item_core,
+	&sd_sys_item_thread,
 	&sd_sys_item_mgm,
 	&sd_sys_item_online,
 	NULL,
@@ -291,10 +308,10 @@ static struct sd_sys_item *l_sys_item_vec[] = {
  * Default system items
  */
 static struct sd_sys_item *l_sys_item_enable_vec[] = {
-	&sd_sys_item_cpu_cnt,
-	&sd_sys_item_cpu_diff,
+	&sd_sys_item_core_cnt,
+	&sd_sys_item_core_diff,
 	&sd_sys_item_mgm_diff,
-	&sd_sys_item_cpu,
+	&sd_sys_item_core,
 	&sd_sys_item_mgm,
 	&sd_sys_item_online,
 	NULL,
@@ -305,9 +322,11 @@ static struct sd_sys_item *l_sys_item_enable_vec[] = {
  */
 static struct sd_cpu_item *l_cpu_item_vec[] = {
 	&sd_cpu_item_type,
-	&sd_cpu_item_cpu_diff,
+	&sd_cpu_item_core_diff,
+	&sd_cpu_item_thread_diff,
 	&sd_cpu_item_mgm_diff,
-	&sd_cpu_item_cpu,
+	&sd_cpu_item_core,
+	&sd_cpu_item_thread,
 	&sd_cpu_item_mgm,
 	&sd_cpu_item_online,
 	NULL,
@@ -318,7 +337,7 @@ static struct sd_cpu_item *l_cpu_item_vec[] = {
  */
 static struct sd_cpu_item *l_cpu_item_enable_vec[] = {
 	&sd_cpu_item_type,
-	&sd_cpu_item_cpu_diff,
+	&sd_cpu_item_core_diff,
 	&sd_cpu_item_mgm_diff,
 	NULL,
 };
@@ -358,6 +377,6 @@ int dg_debugfs_lpar_init(void)
 		return fh;
 	else
 		close(fh);
-	sd_dg_register(&l_sd_dg);
+	sd_dg_register(&l_sd_dg, 1);
 	return 0;
 }
