@@ -24,6 +24,8 @@
 
 static u64 l_update_time_us;
 static long l_2fc_buf_size;
+static int l_use_debugfs_vmd0c;
+static char l_guest_name[64];
 
 /*
  * Diag 2fc data structure definition
@@ -68,6 +70,27 @@ struct l_debugfs_d2fc {
 	char			diag2fc_buf[];
 } __attribute__ ((packed));
 
+ /*
+ * Get local guest name
+ */
+static void l_guest_name_init(void)
+{
+	int level, found = 0;
+	char line[1024];
+	FILE *fh;
+
+	fh = fopen("/proc/sysinfo", "r");
+	if (!fh)
+		ERR_EXIT_ERRNO("Could not open '/proc/sysinfo'");
+	while (fgets(line, sizeof(line), fh)) {
+		if (sscanf(line, "VM%02d Name: %s", &level, l_guest_name) == 2)
+			found = 1;
+	}
+	if (!found)
+		ERR_EXIT("Could find guest name in '/proc/sysinfo'");
+	fclose(fh);
+}
+
 /*
  * Get existing or create new CPU
  */
@@ -137,7 +160,11 @@ static void l_cpu_fill(struct sd_sys *guest, struct l_diag2fc_data *data)
  */
 static void l_sd_sys_fill(struct sd_sys *guest, struct l_diag2fc_data *data)
 {
-	l_cpu_fill(guest, data);
+	if (l_use_debugfs_vmd0c && (strcmp(guest->id, l_guest_name) == 0))
+		dg_debugfs_vmd0c_sys_cpu_fill(guest, data->el_time,
+					      data->vcpus);
+	else
+		l_cpu_fill(guest, data);
 
 	sd_sys_weight_cur_set(guest, data->cpu_shares);
 	sd_sys_weight_max_set(guest, data->cpu_max);
@@ -247,7 +274,9 @@ static struct sd_sys_item *l_sys_item_vec[] = {
 	&sd_sys_item_cpu_cnt,
 	&sd_sys_item_cpu_oper_cnt,
 	&sd_sys_item_cpu_diff,
+	&sd_sys_item_mgm_diff,
 	&sd_sys_item_cpu,
+	&sd_sys_item_mgm,
 	&sd_sys_item_online,
 	&sd_sys_item_mem_use,
 	&sd_sys_item_mem_max,
@@ -275,7 +304,9 @@ static struct sd_sys_item *l_sys_item_enable_vec[] = {
  */
 static struct sd_cpu_item *l_cpu_item_vec[] = {
 	&sd_cpu_item_cpu_diff,
+	&sd_cpu_item_mgm_diff,
 	&sd_cpu_item_cpu,
+	&sd_cpu_item_mgm,
 	&sd_cpu_item_online,
 	NULL,
 };
@@ -315,12 +346,16 @@ int dg_debugfs_vm_init(void)
 {
 	int fh;
 
+	fh = dg_debugfs_vmd0c_init();
+	if (fh == 0)
+		l_use_debugfs_vmd0c = 1;
 	fh = dg_debugfs_open(DEBUGFS_FILE);
 	if (fh < 0)
 		return fh;
 	else
 		close(fh);
 	l_2fc_buf_size = sizeof(struct l_debugfs_d2fc_hdr);
-	sd_dg_register(&dg_debugfs_vm_dg);
+	l_guest_name_init();
+	sd_dg_register(&dg_debugfs_vm_dg, 0);
 	return 0;
 }
