@@ -21,6 +21,8 @@
  */
 struct sd_cpu_info {
 	u64	cpu_time_us;
+	u64	thread_time_us;
+	u64	mgm_time_us_set;
 	u64	mgm_time_us;
 	u64	wait_time_us;
 	s64	steal_time_us;
@@ -77,6 +79,7 @@ struct sd_sys {
 	u32			cpu_cnt;
 	u32			cpu_cnt_active;
 	struct util_list	cpu_list;
+	u32			threads_per_core;
 	char			id[SD_SYS_ID_SIZE];
 	struct sd_sys_name	name;
 	struct sd_mem		mem;
@@ -231,8 +234,14 @@ static inline void sd_cpu_cpu_time_us_set(struct sd_cpu *cpu, u64 value)
 	cpu->d_cur->cpu_time_us = value;
 }
 
+static inline void sd_cpu_thread_time_us_set(struct sd_cpu *cpu, u64 value)
+{
+	cpu->d_cur->thread_time_us = value;
+}
+
 static inline void sd_cpu_mgm_time_us_set(struct sd_cpu *cpu, u64 value)
 {
+	cpu->d_cur->mgm_time_us_set = 1;
 	cpu->d_cur->mgm_time_us = value;
 }
 
@@ -279,6 +288,7 @@ struct sd_cpu_item {
 	enum sd_item_type	type;
 	int			offset;
 	char			*desc;
+	int (*fn_set)(struct sd_cpu_item *, struct sd_cpu *);
 	u64 (*fn_u64)(struct sd_cpu_item *, struct sd_cpu *);
 	s64 (*fn_s64)(struct sd_cpu_item *, struct sd_cpu *);
 	char *(*fn_str)(struct sd_cpu_item *, struct sd_cpu *);
@@ -293,6 +303,11 @@ extern int sd_cpu_item_cnt(void);
 /*
  * Item access functions
  */
+static inline u64 sd_cpu_item_set(struct sd_cpu_item *item, struct sd_cpu *cpu)
+{
+	return (item->fn_set == NULL) ? 1 : item->fn_set(item, cpu);
+}
+
 static inline u64 sd_cpu_item_u64(struct sd_cpu_item *item,
 				  struct sd_cpu *cpu)
 {
@@ -320,10 +335,14 @@ static inline char *sd_cpu_item_str(struct sd_cpu_item *item,
 extern struct sd_cpu_item sd_cpu_item_type;
 extern struct sd_cpu_item sd_cpu_item_state;
 extern struct sd_cpu_item sd_cpu_item_cpu_diff;
+extern struct sd_cpu_item sd_cpu_item_core_diff;
+extern struct sd_cpu_item sd_cpu_item_thread_diff;
 extern struct sd_cpu_item sd_cpu_item_mgm_diff;
 extern struct sd_cpu_item sd_cpu_item_wait_diff;
 extern struct sd_cpu_item sd_cpu_item_steal_diff;
 extern struct sd_cpu_item sd_cpu_item_cpu;
+extern struct sd_cpu_item sd_cpu_item_core;
+extern struct sd_cpu_item sd_cpu_item_thread;
 extern struct sd_cpu_item sd_cpu_item_mgm;
 extern struct sd_cpu_item sd_cpu_item_wait;
 extern struct sd_cpu_item sd_cpu_item_steal;
@@ -338,6 +357,7 @@ struct sd_sys_item {
 	int			offset;
 	char			*desc;
 	int			info;
+	int (*fn_set)(struct sd_sys_item *, struct sd_sys *);
 	u64 (*fn_u64)(struct sd_sys_item *, struct sd_sys *);
 	s64 (*fn_s64)(struct sd_sys_item *, struct sd_sys *);
 };
@@ -351,6 +371,11 @@ extern int sd_sys_item_cnt(void);
 /*
  * Item access functions
  */
+static inline int sd_sys_item_set(struct sd_sys *sys, struct sd_sys_item *item)
+{
+	return (item->fn_set == NULL) ? 1 : item->fn_set(item, sys);
+}
+
 static inline u64 sd_sys_item_u64(struct sd_sys *sys,
 				  struct sd_sys_item *item)
 {
@@ -373,15 +398,21 @@ static inline char *sd_sys_item_str(struct sd_sys *sys,
  * Predefined System items
  */
 extern struct sd_sys_item sd_sys_item_cpu_cnt;
+extern struct sd_sys_item sd_sys_item_core_cnt;
+extern struct sd_sys_item sd_sys_item_thread_cnt;
 extern struct sd_sys_item sd_sys_item_cpu_oper_cnt;
 extern struct sd_sys_item sd_sys_item_cpu_deconf_cnt;
 extern struct sd_sys_item sd_sys_item_cpu_stop_cnt;
 extern struct sd_sys_item sd_sys_item_cpu_diff;
+extern struct sd_sys_item sd_sys_item_core_diff;
+extern struct sd_sys_item sd_sys_item_thread_diff;
 extern struct sd_sys_item sd_sys_item_mgm_diff;
 extern struct sd_sys_item sd_sys_item_wait_diff;
 extern struct sd_sys_item sd_sys_item_steal_diff;
 
 extern struct sd_sys_item sd_sys_item_cpu;
+extern struct sd_sys_item sd_sys_item_core;
+extern struct sd_sys_item sd_sys_item_thread;
 extern struct sd_sys_item sd_sys_item_mgm;
 extern struct sd_sys_item sd_sys_item_wait;
 extern struct sd_sys_item sd_sys_item_steal;
@@ -412,7 +443,8 @@ struct sd_dg {
 	struct sd_cpu_item	**cpu_item_enable_vec;
 };
 
-void sd_dg_register(struct sd_dg *);
+void sd_dg_register(struct sd_dg *, int);
+int sd_dg_has_core_data(void);
 
 /*
  * Iterators
@@ -447,6 +479,11 @@ void sd_dg_register(struct sd_dg *);
 #define SD_CPU_INFO_OFFSET(x) \
 	((unsigned long)(void *)&(((struct sd_cpu_info *) NULL)->x))
 
+static inline int l_cpu_info_set(struct sd_cpu_info *info, unsigned long offset)
+{
+	return (int)*(u64 *)(((char *) info) + offset - 8);
+}
+
 static inline u64 l_cpu_info_u64(struct sd_cpu_info *info,
 				 unsigned long offset)
 {
