@@ -73,6 +73,14 @@ static s64 l_cpu_diff_s64(struct sd_cpu_item *item, struct sd_cpu *cpu)
 	return l_cpu_diff(item, cpu, 1);
 }
 
+/*
+ * Return true, if CPU item has been set
+ */
+static inline int l_cpu_item_set(struct sd_cpu_item *item, struct sd_cpu *cpu)
+{
+	return l_cpu_info_set(cpu->d_cur, item->offset);
+}
+
 /*
  * Return cpu item value
  */
@@ -105,6 +113,14 @@ struct sd_cpu_item sd_cpu_item_state = {
 	.fn_str		= l_cpu_state,
 };
 
+struct sd_cpu_item sd_cpu_item_core_diff = {
+	.table_col = TABLE_COL_TIME_DIFF_SUM(table_col_unit_perc, 'c', "core"),
+	.type	= SD_TYPE_U64,
+	.offset = SD_CPU_INFO_OFFSET(cpu_time_us),
+	.desc	= "Core dispatch time per second",
+	.fn_u64	= l_cpu_diff_u64,
+};
+
 struct sd_cpu_item sd_cpu_item_cpu_diff = {
 	.table_col = TABLE_COL_TIME_DIFF_SUM(table_col_unit_perc, 'c', "cpu"),
 	.type	= SD_TYPE_U64,
@@ -113,11 +129,20 @@ struct sd_cpu_item sd_cpu_item_cpu_diff = {
 	.fn_u64	= l_cpu_diff_u64,
 };
 
+struct sd_cpu_item sd_cpu_item_thread_diff = {
+	.table_col = TABLE_COL_TIME_DIFF_SUM(table_col_unit_perc, 'e', "the"),
+	.type	= SD_TYPE_U64,
+	.offset = SD_CPU_INFO_OFFSET(thread_time_us),
+	.desc	= "Thread time per second",
+	.fn_u64	= l_cpu_diff_u64,
+};
+
 struct sd_cpu_item sd_cpu_item_mgm_diff = {
 	.table_col = TABLE_COL_TIME_DIFF_SUM(table_col_unit_perc, 'm', "mgm"),
 	.type	= SD_TYPE_U64,
 	.offset = SD_CPU_INFO_OFFSET(mgm_time_us),
 	.desc	= "Management time per second",
+	.fn_set	= l_cpu_item_set,
 	.fn_u64	= l_cpu_diff_u64,
 };
 
@@ -138,6 +163,14 @@ struct sd_cpu_item sd_cpu_item_steal_diff = {
 	.fn_s64	= l_cpu_diff_s64,
 };
 
+struct sd_cpu_item sd_cpu_item_core = {
+	.table_col = TABLE_COL_TIME_SUM(table_col_unit_hm, 'C', "core+"),
+	.type	= SD_TYPE_U64,
+	.offset = SD_CPU_INFO_OFFSET(cpu_time_us),
+	.desc	= "Total core dispatch time",
+	.fn_u64	= l_cpu_item_64,
+};
+
 struct sd_cpu_item sd_cpu_item_cpu = {
 	.table_col = TABLE_COL_TIME_SUM(table_col_unit_hm, 'C', "cpu+"),
 	.type	= SD_TYPE_U64,
@@ -146,11 +179,20 @@ struct sd_cpu_item sd_cpu_item_cpu = {
 	.fn_u64	= l_cpu_item_64,
 };
 
+struct sd_cpu_item sd_cpu_item_thread = {
+	.table_col = TABLE_COL_TIME_SUM(table_col_unit_hm, 'E', "the+"),
+	.type	= SD_TYPE_U64,
+	.offset = SD_CPU_INFO_OFFSET(thread_time_us),
+	.desc	= "Total thread time",
+	.fn_u64	= l_cpu_item_64,
+};
+
 struct sd_cpu_item sd_cpu_item_mgm = {
 	.table_col = TABLE_COL_TIME_SUM(table_col_unit_hm, 'M', "mgm+"),
 	.type	= SD_TYPE_U64,
 	.offset = SD_CPU_INFO_OFFSET(mgm_time_us),
 	.desc	= "Total management time",
+	.fn_set	= l_cpu_item_set,
 	.fn_u64	= l_cpu_item_64,
 };
 
