@@ -36,6 +36,16 @@ static u64 l_sys_cpu_cnt(struct sd_sys_item *item, struct sd_sys *sys)
 	return l_sys_cpu_cnt_gen(sys, SD_CPU_STATE_UNKNOWN, 1);
 }
 
+/*
+ * Count all threads of system
+ */
+static u64 l_sys_thread_cnt(struct sd_sys_item *item, struct sd_sys *sys)
+{
+	(void) item;
+	return l_sys_cpu_cnt_gen(sys, SD_CPU_STATE_UNKNOWN, 1) *
+			sys->threads_per_core;
+}
+
 /*
  * Count CPUs of system with state stopped
  */
@@ -67,6 +77,22 @@ static u64 l_sys_cpu_dc_cnt(struct sd_sys_item *item,
 	return l_sys_cpu_cnt_gen(sys, SD_CPU_STATE_DECONFIG, 0);
 }
 
+/*
+ * Check if CPU info is set
+ */
+static int l_sys_cpu_info_set(struct sd_sys_item *item, struct sd_sys *sys)
+{
+	struct sd_cpu *cpu;
+
+	sd_cpu_iterate(sys, cpu) {
+		if (!sd_cpu_type_selected(cpu->type))
+			continue;
+		if (!l_cpu_info_set(cpu->d_cur, item->offset))
+			return 0;
+	}
+	return 1;
+}
+
 /*
  * Get u64 system item value from "sys"
  */
@@ -183,6 +209,13 @@ static s64 l_sys_cpu_info_diff_s64(struct sd_sys_item *item, struct sd_sys *sys)
 /*
  * System item definitions
  */
+struct sd_sys_item sd_sys_item_core_cnt = {
+	.table_col = TABLE_COL_CNT_SUM('#', "#core"),
+	.type	= SD_TYPE_U32,
+	.desc	= "Number of cores",
+	.fn_u64	= l_sys_cpu_cnt,
+};
+
 struct sd_sys_item sd_sys_item_cpu_cnt = {
 	.table_col = TABLE_COL_CNT_SUM('#', "#cpu"),
 	.type	= SD_TYPE_U32,
@@ -190,6 +223,13 @@ struct sd_sys_item sd_sys_item_cpu_cnt = {
 	.fn_u64	= l_sys_cpu_cnt,
 };
 
+struct sd_sys_item sd_sys_item_thread_cnt = {
+	.table_col = TABLE_COL_CNT_SUM('T', "#the"),
+	.type	= SD_TYPE_U32,
+	.desc	= "Number of threads",
+	.fn_u64	= l_sys_thread_cnt,
+};
+
 struct sd_sys_item sd_sys_item_cpu_oper_cnt = {
 	.table_col = TABLE_COL_CNT_SUM('O', "#cpuop"),
 	.type	= SD_TYPE_U32,
@@ -211,6 +251,14 @@ struct sd_sys_item sd_sys_item_cpu_deconf_cnt = {
 	.fn_u64	= l_sys_cpu_dc_cnt,
 };
 
+struct sd_sys_item sd_sys_item_core_diff = {
+	.table_col = TABLE_COL_TIME_DIFF_SUM(table_col_unit_perc, 'c', "core"),
+	.offset = SD_CPU_INFO_OFFSET(cpu_time_us),
+	.type	= SD_TYPE_U64,
+	.desc	= "Core dispatch time per second",
+	.fn_u64	= l_sys_cpu_info_diff_u64,
+};
+
 struct sd_sys_item sd_sys_item_cpu_diff = {
 	.table_col = TABLE_COL_TIME_DIFF_SUM(table_col_unit_perc, 'c', "cpu"),
 	.offset = SD_CPU_INFO_OFFSET(cpu_time_us),
@@ -219,11 +267,20 @@ struct sd_sys_item sd_sys_item_cpu_diff = {
 	.fn_u64	= l_sys_cpu_info_diff_u64,
 };
 
+struct sd_sys_item sd_sys_item_thread_diff = {
+	.table_col = TABLE_COL_TIME_DIFF_SUM(table_col_unit_perc, 'e', "the"),
+	.offset = SD_CPU_INFO_OFFSET(thread_time_us),
+	.type	= SD_TYPE_U64,
+	.desc	= "Thread time per second",
+	.fn_u64	= l_sys_cpu_info_diff_u64,
+};
+
 struct sd_sys_item sd_sys_item_mgm_diff = {
 	.table_col = TABLE_COL_TIME_DIFF_SUM(table_col_unit_perc, 'm', "mgm"),
 	.offset = SD_CPU_INFO_OFFSET(mgm_time_us),
 	.type	= SD_TYPE_U64,
 	.desc	= "Management time per second",
+	.fn_set	= l_sys_cpu_info_set,
 	.fn_u64	= l_sys_cpu_info_diff_u64,
 };
 
@@ -244,6 +301,14 @@ struct sd_sys_item sd_sys_item_steal_diff = {
 	.fn_s64	= l_sys_cpu_info_diff_s64,
 };
 
+struct sd_sys_item sd_sys_item_core = {
+	.table_col = TABLE_COL_TIME_SUM(table_col_unit_hm, 'C', "core+"),
+	.offset = SD_CPU_INFO_OFFSET(cpu_time_us),
+	.type	= SD_TYPE_U64,
+	.desc	= "Total core dispatch time",
+	.fn_u64	= l_sys_cpu_info_sum_u64,
+};
+
 struct sd_sys_item sd_sys_item_cpu = {
 	.table_col = TABLE_COL_TIME_SUM(table_col_unit_hm, 'C', "cpu+"),
 	.offset = SD_CPU_INFO_OFFSET(cpu_time_us),
@@ -252,6 +317,14 @@ struct sd_sys_item sd_sys_item_cpu = {
 	.fn_u64	= l_sys_cpu_info_sum_u64,
 };
 
+struct sd_sys_item sd_sys_item_thread = {
+	.table_col = TABLE_COL_TIME_SUM(table_col_unit_hm, 'E', "the+"),
+	.offset = SD_CPU_INFO_OFFSET(thread_time_us),
+	.type	= SD_TYPE_U64,
+	.desc	= "Total thread time",
+	.fn_u64	= l_sys_cpu_info_sum_u64,
+};
+
 struct sd_sys_item sd_sys_item_wait = {
 	.table_col = TABLE_COL_TIME_SUM(table_col_unit_hm, 'W', "wait+"),
 	.offset = SD_CPU_INFO_OFFSET(wait_time_us),
@@ -265,6 +338,7 @@ struct sd_sys_item sd_sys_item_mgm = {
 	.offset = SD_CPU_INFO_OFFSET(mgm_time_us),
 	.type	= SD_TYPE_U64,
 	.desc	= "Total management time",
+	.fn_set	= l_sys_cpu_info_set,
 	.fn_u64	= l_sys_cpu_info_sum_u64,
 };
 
