@@ -46,7 +46,6 @@ static void l_mark_key_add(struct table *t, char *str)
 	key = ht_zalloc(sizeof(*key));
 	strncpy(key->str, str, sizeof(key->str));
 	util_list_add_tail(&t->mark_key_list, key);
-	t->mark_keys_cnt++;
 }
 
 /*
@@ -60,7 +59,6 @@ static void l_mark_key_remove(struct table *t, char *str)
 		if (strcmp(str, key->str) == 0) {
 			util_list_remove(&t->mark_key_list, key);
 			ht_free(key);
-			t->mark_keys_cnt--;
 			return;
 		}
 	}
@@ -80,7 +78,6 @@ void table_row_mark_del_all(struct table *t)
 		util_list_remove(&t->mark_key_list, key);
 		ht_free(key);
 	}
-	t->mark_keys_cnt = 0;
 }
 
 /*
@@ -358,6 +355,8 @@ static void l_row_last_agg(struct table *t, struct table_row *table_row)
 		struct table_entry *e_last = &t->row_last->entries[col_nr];
 		struct table_entry *e_new = &table_row->entries[col_nr];
 
+		if (!e_new->set)
+			continue;
 		switch (col->agg) {
 		case TABLE_COL_AGG_SUM:
 			l_entry_sum(col->type, e_last, e_new);
@@ -368,6 +367,7 @@ static void l_row_last_agg(struct table *t, struct table_row *table_row)
 		case TABLE_COL_AGG_NONE:
 			break;
 		}
+		e_last->set = 1;
 	}
 }
 
