@@ -285,6 +285,7 @@ struct table_entry {
 			s64	v2;
 		} s64;
 	} d;
+	int			set;
 	char			str[TABLE_STR_MAX];
 };
 
@@ -293,7 +294,6 @@ struct table_entry {
  */
 struct table_row {
 	struct util_list_node	list;
-	int			entry_count;
 	struct table_entry	*entries;
 	int			marked;
 };
@@ -322,7 +322,6 @@ struct table {
 	int 			row_nr_select;
 	int			ready;
 	struct util_list	mark_key_list;
-	unsigned int		mark_keys_cnt;
 	int			attr_sorted_table;
 	int			attr_first_bold;
 	int			attr_with_units;
@@ -390,6 +389,7 @@ static inline void table_row_entry_u64_add(struct table_row *table_row,
 					   u64 value)
 {
 	table_row->entries[table_col->p->col_nr].d.u64.v1 = value;
+	table_row->entries[table_col->p->col_nr].set = 1;
 }
 
 static inline void table_row_entry_s64_add(struct table_row *table_row,
@@ -397,6 +397,7 @@ static inline void table_row_entry_s64_add(struct table_row *table_row,
 					   s64 value)
 {
 	table_row->entries[table_col->p->col_nr].d.s64.v1 = value;
+	table_row->entries[table_col->p->col_nr].set = 1;
 }
 
 static inline void table_row_entry_u64_add_pair(struct table_row *table_row,
@@ -405,6 +406,7 @@ static inline void table_row_entry_u64_add_pair(struct table_row *table_row,
 {
 	table_row->entries[table_col->p->col_nr].d.u64.v1 = value1;
 	table_row->entries[table_col->p->col_nr].d.u64.v2 = value2;
+	table_row->entries[table_col->p->col_nr].set = 1;
 }
 
 static inline void table_row_entry_str_add(struct table_row *table_row,
@@ -413,6 +415,7 @@ static inline void table_row_entry_str_add(struct table_row *table_row,
 {
 	assert(strlen(str) < TABLE_STR_MAX);
 	strcpy(table_row->entries[table_col->p->col_nr].str, str);
+	table_row->entries[table_col->p->col_nr].set = 1;
 }
 
 /*
