@@ -13,6 +13,7 @@
 #define L_VISUAL_ROW_CNT	45
 #define L_COL_FMT_STR_0		"%.0lf"
 #define L_COL_FMT_STR_2		"%.2lf"
+#define L_COL_NOT_SET_STR	"-"
 
 /*
  * Helper: Divide value and format it
@@ -22,6 +23,8 @@ static int l_unit_raw_div(struct table_col *col, struct table_entry *e,
 {
 	double v1;
 
+	if (!e->set)
+		return snprintf(e->str, sizeof(e->str), L_COL_NOT_SET_STR);
 	switch (col->type) {
 	case TABLE_COL_TYPE_U64:
 		v1 = ((double) e->d.u64.v1) / divisor;
@@ -40,6 +43,8 @@ static int l_unit_raw_div(struct table_col *col, struct table_entry *e,
  */
 static int l_unit_raw(struct table_col *col, struct table_entry *e)
 {
+	if (!e->set)
+		return snprintf(e->str, sizeof(e->str), L_COL_NOT_SET_STR);
 	switch (col->type) {
 	case TABLE_COL_TYPE_U64:
 		return snprintf(e->str, sizeof(e->str), "%llu", e->d.u64.v1);
@@ -219,6 +224,9 @@ static int l_unit_hm_u64(char *str, u64 v1, int negative)
 
 static int l_unit_hm(struct table_col *col, struct table_entry *e)
 {
+	if (!e->set)
+		return snprintf(e->str, sizeof(e->str), L_COL_NOT_SET_STR);
+
 	switch (col->type) {
 	case TABLE_COL_TYPE_U64:
 		return l_unit_hm_u64(e->str, e->d.u64.v1, 0);
@@ -262,6 +270,9 @@ static int l_unit_dhm_u64(char *str, u64 v1, int negative)
 
 static int l_unit_dhm(struct table_col *col, struct table_entry *e)
 {
+	if (!e->set)
+		return snprintf(e->str, sizeof(e->str), L_COL_NOT_SET_STR);
+
 	switch (col->type) {
 	case TABLE_COL_TYPE_U64:
 		return l_unit_dhm_u64(e->str, e->d.u64.v1, 0);
