@@ -10,17 +10,17 @@
 #ifndef TBOX_H
 #define TBOX_H
 
-#include "list.h"
+#include "util.h"
 
 #define TBOX_MAX_STR	120
 
 struct tbox_line {
-	struct list	list;
-	char		*str;
+	struct util_list_node	list;
+	char			*str;
 };
 
 struct tbox {
-	struct list		line_list;
+	struct util_list	line_list;
 	int			line_cnt;
 	int			line_start;
 	int			tbox_ready;
