@@ -154,8 +154,11 @@ static void l_cpu_add(struct sd_cpu *cpu)
 	cpu_id = atoi(sd_cpu_id(cpu));
 	table_row_entry_u64_add(table_row, &l_cpu_col, cpu_id);
 
-	sd_cpu_item_iterate(item, i)
+	sd_cpu_item_iterate(item, i) {
+		if (!sd_cpu_item_set(item, cpu))
+			continue;
 		l_cpu_item_add(table_row, cpu, item);
+	}
 	l_cpu_add_visual(table_row, cpu);
 	table_row_add(l_t, table_row);
 }
@@ -331,9 +334,16 @@ void win_sys_init(void)
 	struct table_col **col_vec;
 	struct sd_cpu_item *item;
 	struct table_col *col;
-	char **col_desc_vec;
+	char **col_desc_vec, *vis_str;
 	unsigned int i, item_cnt;
 
+	if (sd_dg_has_core_data()) {
+		strcpy(l_cpu_col.head, "coreid");
+		vis_str = "Visualization of core dispatch time per second";
+	} else {
+		vis_str = "Visualization of CPU time per second";
+	}
+
 	/* Alloc table and add columns */
 	l_t = table_new(1, 1, 1, 1);
 	table_col_add(l_t, &l_cpu_col);
@@ -351,7 +361,7 @@ void win_sys_init(void)
 		col_desc_vec[i] = item->desc;
 	}
 	col_vec[i] = &l_vis_col;
-	col_desc_vec[i] = "Visualization of CPU time per second";
+	col_desc_vec[i] = vis_str;
 	table_col_add(l_t, &l_vis_col);
 
 	/* Enable fields */
@@ -371,6 +381,7 @@ void win_sys_init(void)
 	/* Initialize help and fields window */
 	l_win_fields = win_fields_new(l_t, col_vec, col_desc_vec);
 	l_win_help = win_help_new(&win_sys);
+
 	l_initialized = 1;
 }
 
