@@ -24,6 +24,9 @@
 #define TOOLS_LIBDIR	STRINGIFY (S390_TOOLS_LIBDIR)
 #define TOOLS_SYSCONFDIR STRINGIFY (S390_TOOLS_SYSCONFDIR)
 
+#define __packed __attribute__((packed))
+#define __aligned(x) __attribute__((aligned(x)))
+
 typedef unsigned long long	u64;
 typedef signed long long	s64;
 typedef unsigned int		u32;
