@@ -1,17 +1,12 @@
 /*
- *
- * xcec-bridge
- *
- * Copyright IBM Corp. 2003, 2006.
- *
- * Authors: Utz Bacher <utz.bacher@de.ibm.com>
- * thanks a lot to Frank Pavlic <pavlic@de.ibm.com>
+ * xcec-bridge - HiperSockets Network Concentrator
  *
  * Parameters:
  *   also_unicast     - uni-, multi-, broadcast is bridged
  *   <no parameters>  - multi-, broadcast is bridged
  *   only broadcast   - only broadcast is bridged
- * 
+ *
+ * Copyright IBM Corp. 2003, 2006
  */
 
 #include <sys/time.h>
@@ -43,9 +38,6 @@
 
 #define DEV_NAME_LEN IFNAMSIZ
 
-#define PROC_QETH_FILE "/proc/qeth"
-#define PROC_QETH_FILE_WIDTH 100
-
 #define BUFFER_LEN 65536
 
 int so_sndbuf=(8*1024*1024);
@@ -203,99 +195,6 @@ int interface_in_list(struct int_sock *item,struct int_sock *list)
 	return 0;
 }
 
-int read_proc(struct int_sock **nlist)
-{
-	FILE *fh;
-	char buf[PROC_QETH_FILE_WIDTH];
-	int retval,line_no = 2;
-	char r_dev_name[PROC_QETH_FILE_WIDTH];
-	char r_rtr[PROC_QETH_FILE_WIDTH];
-	int r;
-	struct int_sock *i = NULL;
-
-	fh=fopen(PROC_QETH_FILE,"r");
-	if (!fh) {
-		syslog(LOG_ERR,"can't open %s -- won't use different " \
-		       "interfaces",PROC_QETH_FILE);
-		return 1;
-	}
-	/* read the two header lines */
-	if ( (!fgets(buf,PROC_QETH_FILE_WIDTH,fh)) ||
-	     (!fgets(buf,PROC_QETH_FILE_WIDTH,fh)) ) {
-		syslog(LOG_ERR,"can't read header from %s -- "
-		       "won't use different interfaces",PROC_QETH_FILE);
-		fclose(fh);
-		return 1;
-	}
-
-	do {
-		line_no++;
-
-		strcpy(r_dev_name,"");
-		/* format string: devnos chpid dev_name
-		 * dev_name is what we're interested in */
-		retval=fscanf(fh,"%*s %*s %s %*s %*s %*s %*s %s",
-			      r_dev_name,r_rtr);
-		if (retval==EOF) {
-			break;
-		}
-
-		/* read the rest of the line */
-		do {
-			r=fgetc(fh);
-		} while ((r!=EOF)&&(r!='\n'));
-
-		/* dull right now, but maybe useful in the future */
-		if (retval!=2) {
-			syslog(LOG_ERR,"can't interpret line %i from " \
-			       "%s -- some interface might not be used",
-			       line_no,PROC_QETH_FILE);
-			continue;
-		}
-
-		/* we only want to forward between affected interfaces:
-		 * mc, pri, sec, p.c, s.c, mix */
-		if (!(
-		      (!strcmp(r_rtr,"mc"))||
-		      (!strcmp(r_rtr,"mc+"))||
-		      (!strcmp(r_rtr,"p.c"))||
-		      (!strcmp(r_rtr,"s.c"))||
-		      (!strcmp(r_rtr,"p+c"))||
-		      (!strcmp(r_rtr,"s+c")) )) {
-			continue;
-		}
-
-		i=malloc(sizeof(struct int_sock));
-		if (!i) {
-			syslog(LOG_ERR,"no memory while reading from %s -- " \
-				       "some interface might not be used",
-				       PROC_QETH_FILE);
-			continue;
-		}
-
-		/* as soon as we have one interface echoeing back broadcasts
-		 * to us, we don't bridge broadcast traffic */
-		if (!(
-		      (!strcmp(r_rtr,"mc+"))||
-		      (!strcmp(r_rtr,"p+c"))||
-		      (!strcmp(r_rtr,"s+c"))
-		     )) {
-			do_broadcast_bridging=0;
-		}
-
-		i->mtu_warning=0;
-		strncpy(i->dev_name,r_dev_name,DEV_NAME_LEN);
-		if (!strncmp(r_dev_name,"hsi",3)) {
-			i->features=I_S_FEATURE_PASSTHROUGH;
-		}
-
-		i->next = *nlist;
-		*nlist = i;
-	} while (retval!=EOF);
-
-	fclose(fh);
-	return 0;
-}
 
 int read_sys(struct int_sock **nlist)
 {
@@ -397,22 +296,15 @@ void update_interfaces()
 	struct int_sock *new_list=NULL;
 	struct int_sock *i=NULL,*j,*prev;
 	struct int_sock *new_int=NULL;
-	int i_fd,o_fd, rc;
-	struct stat st;
+	int i_fd,o_fd;
 
 	/* if all interfaces are '+'-interfaces, we bridge broadcast */
 	do_broadcast_bridging=1;
 	update_interface_trigger=0;
 	syslog(LOG_DEBUG,"rechecking interfaces");
 
-	rc = stat(PROC_QETH_FILE, &st);
-	if (rc == 0) {
-		if (read_proc(&new_list))
-			return;
-	} else {
-		if (read_sys(&new_list))
-			return;
-	}
+	if (read_sys(&new_list))
+		return;
 
 	for (i=select_set.i_s_list;i;i=i->next) {
 		if (!interface_in_list(i,new_list)) {
@@ -568,11 +460,10 @@ void process_packet(struct int_sock *i_s)
 				       "%s\n",i_s_item->dev_name,
 				       strerror(errno));
 			}
-		} else if (retval!=buffer_len) {
+		} else if (retval != (buffer_len - ETH_HLEN)) {
 			syslog(LOG_WARNING,"sendto sent only %i instead " \
-			       "of %i bytes on %s: %s\n",
-			       retval,buffer_len,i_s->dev_name,
-			       strerror(errno));
+			       "of %i bytes on %s\n",
+			       retval,buffer_len,i_s->dev_name);
 		}
 	}
 }
