@@ -9,6 +9,7 @@
  */
 
 
+#include <ctype.h>
 #include "ipl_tools.h"
 #include "zt_common.h"
 #include "proc.h"
@@ -46,6 +47,7 @@ static const char *const usage_chreipl =
 "  node     IPL from device specified by device node or directory\n"
 "\n"
 "General options:\n"
+"  -f, --force             Allow targets that cannot be verified by the system\n"
 "  -p, --bootparms <PARMS> Boot parameter specification\n"
 "  -h, --help              Print this help, then exit\n"
 "  -v, --version           Print version information, then exit\n"
@@ -59,6 +61,7 @@ static const char *const usage_chreipl =
 "  -l  --lun <LUN>         Logical unit number of the FCP IPL device\n"
 "  -w  --wwpn <WWPN>       World Wide Port Name of the FCP IPL device\n"
 "  -b, --bootprog <BPROG>  Bootprog specification\n"
+"  -L, --loadparm <PARM>   Loadparm specification\n"
 "\n"
 "Options for nss target:\n"
 "  -n, --name <NAME>       Identifier of the NSS\n"
@@ -75,7 +78,7 @@ static struct locals {
 	int			wwpn_set;
 	char			lun[20];	/* 18 character +0x" */
 	int			lun_set;
-	char			busid[9];	/* Bus ID e.g. 0.0.4711 */
+	char			busid[10];	/* Bus ID e.g. 0.0.4711 */
 	int			busid_set;
 	char			dev[15];	/* Device (e.g. dasda) */
 	int			dev_set;
@@ -83,6 +86,7 @@ static struct locals {
 	int			nss_name_set;
 	char			bootparms[4096];
 	int			bootparms_set;
+	int			force_set;
 	enum target_type	target_type;	/* CCW, FCP, NSS or NODE */
 	int			target_type_set;
 	int			target_type_auto_mode;
@@ -95,24 +99,47 @@ static void print_usage_chreipl_exit(void)
 	exit(0);
 }
 
-static int mk_busid(char busid[9], const char *devno)
+static int busid_strtok(char *str, unsigned long max_len, unsigned long *val)
 {
-	int devno_int, cs1, cs2;
+	char *token, *end;
 
-	if (strlen(devno) > 8)
+	token = strtok(str, ".");
+	if (!token)
 		return -1;
-	if (sscanf(devno, "%x.%x.%x", &cs1, &cs2, &devno_int) == 3) {
-		snprintf(busid, 9, "%x.%x.%04x",
-			 cs1, cs2, devno_int);
-		busid[8] = 0;
-		return 0;
+	if (strlen(token) > max_len)
+		return -1;
+	*val = strtoul(token, &end, 16);
+	if (*end)
+		return -1;
+	return 0;
+}
+
+static int mk_busid(char busid_out[9], const char *busid_in)
+{
+	unsigned long devno, cssid = 0, ssid = 0;
+	char busid_tmp[10];
+
+	if (strlen(busid_in) > 9)
+		return -1;
+	strcpy(busid_tmp, busid_in);
+	if (strstr(busid_in, ".")) {
+		/* Check xx.x.xxxx full bus-ID format */
+		if (busid_strtok(busid_tmp, 2, &cssid))
+			return -1;
+		if (busid_strtok(NULL, 1, &ssid))
+			return -1;
+		if (busid_strtok(NULL, 4, &devno))
+			return -1;
+		/* Ensure that there are no more additional fields */
+		if (strtok(NULL, "."))
+			return -1;
+	} else {
+		/* Check xxxx short bus-ID format */
+		if (busid_strtok(busid_tmp, 4, &devno))
+			return -1;
 	}
-	if (sscanf(devno, "%x", &devno_int) == 1) {
-		snprintf(busid, 9, "0.0.%04x", devno_int);
-		busid[8] = 0;
-		return 0;
-	}
-	return -1;
+	sprintf(busid_out, "%lx.%lx.%04lx", cssid, ssid, devno);
+	return 0;
 }
 
 static void set_device(const char *busid)
@@ -255,7 +282,8 @@ static void dev_from_part(char *dev_name)
 
 static int set_reipl_type(const char *dev_name)
 {
-	if (strncmp(dev_name, "dasd", strlen("dasd")) == 0)
+	if (strncmp(dev_name, "dasd", strlen("dasd")) == 0 ||
+	    strncmp(dev_name, "vd", strlen("vd")) == 0)
 		l.reipl_type = REIPL_CCW;
 	else if (strncmp(dev_name, "sd", strlen("sd")) == 0)
 		l.reipl_type = REIPL_FCP;
@@ -378,7 +406,7 @@ static void parse_pos_args(char *nargv[], int nargc)
 
 static void check_fcp_opts(void)
 {
-	if (l.loadparm_set || l.nss_name_set)
+	if (l.nss_name_set)
 		ERR_EXIT("Invalid option for \"fcp\" target specified");
 	if (!(l.busid_set && l.wwpn_set && l.lun_set))
 		ERR_EXIT("The \"fcp\" target requires device, WWPN, "
@@ -411,7 +439,7 @@ static void set_target_type(enum target_type tt, int mode_auto)
 
 static void set_target_type_auto(const char *arg)
 {
-	char busid[9];
+	char busid[10];
 
 	if (access(arg, R_OK) == 0) {
 		set_target_type(TT_NODE, 1);
@@ -437,10 +465,11 @@ static void parse_chreipl_options(int argc, char *argv[])
 		{ "loadparm",	 required_argument,	NULL, 'L' },
 		{ "name",	 required_argument,	NULL, 'n' },
 		{ "bootparms",	 required_argument,	NULL, 'p' },
+		{ "force",	 no_argument,		NULL, 'f' },
 		{ "version",	 no_argument,		NULL, 'v' },
 		{ NULL,		 0,			NULL,  0  }
 	};
-	static const char optstr[] = "hcd:vw:l:f:L:b:n:p:";
+	static const char optstr[] = "hcd:vw:l:fL:b:n:p:";
 
 	/* dont run without any argument */
 	if (argc == 1)
@@ -482,6 +511,9 @@ static void parse_chreipl_options(int argc, char *argv[])
 		case 'p':
 			set_bootparms(optarg);
 			break;
+		case 'f':
+			l.force_set = 1;
+			break;
 		case 'v':
 			print_version_exit();
 		default:
@@ -512,12 +544,43 @@ static void verify_write_access(const char *path, const char *attr)
 		ERR_EXIT("System does not allow to set %s", attr);
 }
 
+/*
+ * Check if device is on the cio_ignore blacklist
+ *
+ * IMPLEMENTATION:
+ *
+ * "cio_ignore --is-ignored <busid>" returns 0 if the device is ignored,
+ * 1 for internal errrors, and 2 if the device is not ignored.
+ *
+ * We get the "cio_ignore" exit status by the return code of the system()
+ * function via WEXITSTATUS().
+ *
+ * If no shell is available or the "cio_ignore" tool is not available
+ * we get system() rc != 0 and WEXITSTATUS() = 127.
+ */
+static int is_ignored(const char *busid)
+{
+	const char *fmt = "cio_ignore --is-ignored %s > /dev/null 2>&1";
+	char cmd[256];
+	int rc;
+
+	snprintf(cmd, sizeof(cmd), fmt, busid);
+	rc = system(cmd);
+	if ((rc != -1) && (WEXITSTATUS(rc) == 0))
+		return 1;
+	return 0;
+}
+
 static void chreipl_ccw(void)
 {
 	check_ccw_opts();
 
-	if (!ccw_is_device(l.busid))
+	if (!ccw_is_device(l.busid) && !l.force_set) {
+		if (is_ignored(l.busid))
+			ERR_EXIT("Device is on cio_ignore list, try \"cio_ignore -r %s\"?", l.busid);
 		ERR_EXIT("Could not find DASD CCW device \"%s\"", l.busid);
+	}
+
 	/*
 	 * On old systems that use CCW reipl loadparm cannot be set
 	 */
@@ -543,9 +606,18 @@ static void chreipl_ccw(void)
 static void chreipl_fcp(void)
 {
 	check_fcp_opts();
-	if (!fcp_is_device(l.busid))
+
+	if (!fcp_is_device(l.busid) && !l.force_set) {
+		if (is_ignored(l.busid))
+			ERR_EXIT("Device is on cio_ignore list, try \"cio_ignore -r %s\"?", l.busid);
 		ERR_EXIT("Could not find FCP device \"%s\"", l.busid);
+	}
 	verify_write_access("reipl/fcp/device", "\"fcp\" re-IPL target");
+	/*
+	 * On old systems the FCP reipl loadparm cannot be set
+	 */
+	if (l.loadparm_set)
+		verify_write_access("reipl/fcp/loadparm", "loadparm");
 	if (l.bootparms_set) {
 		verify_write_access("reipl/fcp/scp_data", "boot parameters");
 		if (strlen(l.bootparms) > BOOTPARMS_FCP_MAX)
@@ -555,6 +627,8 @@ static void chreipl_fcp(void)
 	}
 	if (access("/sys/firmware/reipl/fcp/scp_data", W_OK) == 0)
 		write_str(l.bootparms, "reipl/fcp/scp_data");
+	if (access("/sys/firmware/reipl/fcp/loadparm", W_OK) == 0)
+		write_str(l.loadparm, "reipl/fcp/loadparm");
 	write_str(l.busid, "reipl/fcp/device");
 	write_str(l.wwpn, "reipl/fcp/wwpn");
 	write_str(l.lun, "reipl/fcp/lun");
