@@ -3,7 +3,7 @@
  *
  * Shared system functions
  *
- * Copyright IBM Corp. 2008, 2010
+ * Copyright IBM Corp. 2008, 2011
  * Author(s): Hans-Joachim Picht <hans@linux.vnet.ibm.com>
  *            Michael Holzheu <holzheu@linux.vnet.ibm.com>
  */
@@ -58,34 +58,43 @@ void strlow(char *s)
 /*
  * Read a string from a particular file
  */
-void read_str(char *string, const char *file, size_t len)
+void read_str(char *string, const char *path, size_t len)
 {
-	char path[PATH_MAX];
 	size_t rc;
 	FILE *fh;
 
-	snprintf(path, sizeof(path), "/sys/firmware/%s", file);
 	fh = fopen(path, "rb");
 	if (fh == NULL)
-		ERR_EXIT_ERRNO("Could not open \"%s\"", file);
+		ERR_EXIT_ERRNO("Could not open \"%s\"", path);
 	rc = fread(string, 1, len - 1, fh);
 	if (rc == 0 && ferror(fh))
-		ERR_EXIT_ERRNO("Could not read \"%s\"", file);
+		ERR_EXIT_ERRNO("Could not read \"%s\"", path);
 	fclose(fh);
 	string[rc] = 0;
 	if (string[strlen(string) - 1] == '\n')
 		string[strlen(string) - 1] = 0;
 }
 
+/*
+ * Read a string from a particular /sys/firmware file
+ */
+void read_fw_str(char *string, const char *file, size_t len)
+{
+	char path[PATH_MAX];
+
+	snprintf(path, sizeof(path), "/sys/firmware/%s", file);
+	return read_str(string, path, len);
+}
+
 /*
  * Print content of a file (path = dir/file)
  */
-void print_str(const char *fmt, const char *dir, const char *file)
+void print_fw_str(const char *fmt, const char *dir, const char *file)
 {
 	char path[PATH_MAX], str[4096];
 
 	snprintf(path, sizeof(path), "%s/%s", dir, file);
-	read_str(str, path, sizeof(str));
+	read_fw_str(str, path, sizeof(str));
 	printf(fmt, str);
 }
 
@@ -106,3 +115,23 @@ void write_str(char *string, char *file)
 		ERR_EXIT_ERRNO("Could not set \"%s\"", file);
 	close(fh);
 }
+
+/*
+ * Write a string to a file and return ERRNO
+ */
+int write_str_errno(char *string, char *file)
+{
+	char path[PATH_MAX], value[4096];
+	int fh;
+
+	snprintf(value, sizeof(value), "%s\n", string);
+	snprintf(path, sizeof(path), "/sys/firmware/%s", file);
+	fh = open(path, O_WRONLY);
+	if (fh < 0)
+		ERR_EXIT_ERRNO("Could not open \"%s\"", file);
+	if (write(fh, value, strlen(value)) < 0)
+		return errno;
+	close(fh);
+	return 0;
+}
+
