@@ -3,7 +3,7 @@
  *
  * Basic MIB implementation module for the OSA-E subagent
  *
- * The code in this module is typical for a ucd-snmp MIB implementation
+ * The code in this module is typical for a net-snmp MIB implementation
  * information on how this works because the MIB layout is retrieved during
  * startup of the subagent, the magic identifier is not used within this
  * implementation. The var_ function uses the vp->type instead to distinct
@@ -57,7 +57,7 @@ void init_ibmOSAMib(void) {
       exit(1); 
     }
 
-  /* GET ucd-snmp ifNumber/ifIndex/ifDescr from IF-MIB for all interfaces */
+  /* GET net-snmp ifNumber/ifIndex/ifDescr from IF-MIB for all interfaces */
   /* on this system                                                       */
   ifNumber = query_IF_MIB( &if_list );
   if ( ifNumber < 0 )
@@ -479,7 +479,7 @@ unsigned char* var_ibmOSAMib( struct variable *vp,
     {
       get_time( time_buf );	    
       snmp_log( LOG_ERR, "%s var_ibmOSAMib(): IPA returned bad ObjectId - "
-		"cannot convert ucd-snmp oid type\n"
+		"cannot convert net-snmp oid type\n"
 		"var_ibmOSAMib(): rejected Get/Getnext request\n", time_buf );
       free( get_cmd );
       return NULL;
