@@ -6,29 +6,10 @@
  * Copyright IBM Corp. 2002, 2007
  */
 
-#ifdef IN_UCD_SNMP_SOURCE
-/* If we're compiling this file inside the ucd-snmp source tree */
-
-/* This should always be included first before anything else */
-#include <config.h>
-
-/* minimal include directives */
-#include "mibincl.h"
-#include "util_funcs.h"
-
-#else /* !IN_UCD_SNMP_SOURCE */
-
-#ifdef NETSNMP5
 #include <net-snmp/net-snmp-config.h>
 #include <net-snmp/net-snmp-includes.h>
 #include <net-snmp/agent/net-snmp-agent-includes.h>
-#else
-#include <ucd-snmp/ucd-snmp-config.h>
-#include <ucd-snmp/ucd-snmp-includes.h>
-#include <ucd-snmp/ucd-snmp-agent-includes.h>
-#endif
 
-#endif /* !IN_UCD_SNMP_SOURCE */
 #ifndef NETSNMP_DS_APPLICATION_ID
 #define NETSNMP_DS_APPLICATION_ID DS_APPLICATION_ID
 #endif
@@ -55,7 +36,7 @@
 #define QETH_QUERY_IPA_DATA           	_IOWR(QETH_IOC_MAGIC, 7, int )
 #define QETH_CHECK_OSA_DEVICE		_IOWR(QETH_IOC_MAGIC, 8, int )
 #define IFNAME_MAXLEN 16    /* max length for linux interface names */
-#define SUFFIX_MAXLEN 13    /* max length of suffix length for ucd-snmp */
+#define SUFFIX_MAXLEN 13    /* max length of suffix length for net-snmp */
 #define MIB_AREA_LEN  25000 /* default size for register MIB data */
 #define MAX_GET_DATA  4094  /* maximum GET response data length */
 #define GET_AREA_LEN  MAX_GET_DATA + 512  /* size for GET command area length */
