@@ -175,7 +175,7 @@ int main(int argc, char *argv[]) {
 	) {
 		switch(c) {
 			case 'h':
-				fprintf(stderr, help_text);
+				fprintf(stderr, "%s", help_text);
 				exit(0);
 			case 'b':
 				ds.cntrl.blink = 1;
@@ -266,7 +266,7 @@ int main(int argc, char *argv[]) {
 		strchkcpy(ds.message1, argv[optind]);
 		pathname = argv[optind+1];
 	} else {
-		fprintf(stderr, help_text);
+		fprintf(stderr, "%s", help_text);
 		exit(1);
 	}
 
