@@ -12,7 +12,7 @@
 
 #include <stdint.h>
 
-#define MAX_CPUS 128
+#define MAX_CPUS 512
 
 class RegisterSet64
 {
@@ -47,8 +47,8 @@ public:
 	RegisterContent64(const RegisterContent64&);
 	RegisterSet64 getRegisterSet(int cpu);
 	void addRegisterSet(const RegisterSet64&);
-	inline int getNumCpus(void) { return nrCpus;}
-	
+	inline int getNumCpus(void) const { return nrCpus; }
+
 	RegisterSet64 regSets[MAX_CPUS];
 private:
 	int nrCpus;
@@ -61,8 +61,8 @@ public:
 	RegisterContent32(const RegisterContent32&);
 	RegisterSet32 getRegisterSet(int cpu);
 	void addRegisterSet(const RegisterSet32&);
-	inline int getNumCpus(void) { return nrCpus;}
-	
+	inline int getNumCpus(void) const { return nrCpus; }
+
 	RegisterSet32 regSets[MAX_CPUS];
 private:
 	int nrCpus;
