@@ -3,8 +3,9 @@
  * File...........: s390-tools/vmur/vmur.cpp
  * Author(s)......: Frank Munzert <munzert@de.ibm.com>
  *                  Michael Holzheu <holzheu@de.ibm.com>
+ *                  Hendrik Brueckner <brueckner@linux.vnet.ibm.com>
  *
- * Copyright IBM Corp. 2007
+ * Copyright IBM Corp. 2007, 2015
  *
  *************************************************************************/
 
@@ -38,10 +39,10 @@ static char *prog_name;
 
 /* Short description */
 static const char tool_name[] =
-	"vmur: Control virtual reader, punch and printer";
+	"vmur: Control virtual reader, punch, and printer";
 
 /* Copyright notice */
-static const char copyright_notice[] = "Copyright IBM Corp. 2007";
+static const char copyright_notice[] = "Copyright IBM Corp. 2007, 2015";
 
 /*
  * Structure vmur is used to store the command line parameters and
@@ -80,6 +81,18 @@ struct vmur {
 	enum spoolfile_fmt spoolfile_fmt;
 	struct sigaction sigact;
 	iconv_t iconv;
+	int   lock_fd;
+	/* ur device spool state */
+	char  spool_restore_cmd[MAXCMDLEN];
+	int   spool_restore_needed;
+	char  spool_class;
+	int   spool_class_specified;
+	char  spool_dest[9];
+	int   spool_dest_specified;
+	char  spool_form[9];
+	int   spool_form_specified;
+	char  spool_dist[9];
+	int   spool_dist_specified;
 } vmur_info;
 
 /*
@@ -146,7 +159,7 @@ static char HELP_TEXT[] =
 "       vmur order   [OPTIONS] [SPOOLID]\n"
 "       vmur list    [OPTIONS] [SPOOLID]\n"
 "\n"
-"Control virtual reader, punch and printer. Available commands are:\n"
+"Control virtual reader, punch, and printer. Available commands are:\n"
 "  * REceive: Receive spool files from reader queue\n"
 "  * PUNch:   Punch a file to punch queue\n"
 "  * PRint:   Print a file to printer queue\n"
@@ -171,6 +184,7 @@ static char HELP_TEXT[] =
 "-O, --stdout             Write spool file to stdout.\n"
 "-f, --force              Overwrite files without prompt.\n"
 "-H, --hold               Hold spool file in reader after receive.\n"
+"-C, --class              Specify the spool class to match a reader file.\n"
 "\n"
 "Options for 'punch' and 'print' command:\n"
 "\n"
@@ -189,6 +203,10 @@ static char HELP_TEXT[] =
 "-N, --name               Name of new spool file.\n"
 "-f, --force              Convert file name to valid spool file name\n"
 "                         automatically without prompt.\n"
+"-C, --class              Spool class to be assigned to the created spool file.\n"
+"    --form               Form to be assigned to the created spool file.\n"
+"    --dest               Destination to be assigned to the created spool file.\n"
+"    --dist               Distribution code for the resulting spool file.\n"
 "\n"
 "Options for 'purge' command:\n"
 "\n"
@@ -285,7 +303,7 @@ static void _cpcmd(char *cpcmd, char **resp, int *rc, int retry, int upper)
 
 	fd = open(VMCP_DEVICE_NODE, O_RDWR);
 	if (fd == -1)
-		ERR_EXIT("Could not issue cp command: \"%s\"\n"
+		ERR_EXIT("Could not issue CP command: \"%s\"\n"
 			 "Ensure that vmcp kernel module is loaded!\n", cmd);
 
 	do {
@@ -421,10 +439,11 @@ static int get_ur_devno(int minor)
 		ERR_EXIT("Could not read %s (err = %i)\n",
 			    SYSFS_CLASS_DIR, errno);
 	else
-		ERR_EXIT("Device not online\n");
+		ERR_EXIT("Device is not online\n");
 found:
 	if (sscanf(bus_id, "0.0.%x", &devno) != 1)
-		ERR_EXIT("Could not extract devno from %s\n", direntp->d_name);
+		ERR_EXIT("Could not extract device number from %s\n",
+			 direntp->d_name);
 	closedir(fd);
 	return devno;
 }
@@ -473,6 +492,135 @@ static int get_driver_major(unsigned long *major)
 	ERR_EXIT("Unit record device driver not loaded.\n");
 }
 
+/*
+ * Copy printable characters
+ */
+static void strncpy_graph(char *dest, const char *src, size_t len)
+{
+	size_t n;
+
+	for (n = 0; n < len; n++) {
+		if (!isgraph(src[n]))
+			break;
+		dest[n] = src[n];
+	}
+	dest[n] = '\0';
+}
+
+/*
+ * Create CP command to restore spooling options
+ */
+static void save_spool_options(struct vmur *info)
+{
+	char cmd[MAXCMDLEN], *resp;
+	char cl, value[9], *tmp;
+	int n;
+
+	/* Retrieve spooling options for ur device */
+	sprintf(cmd, "QUERY VIRTUAL %X", info->devno);
+	cpcmd(cmd, &resp, NULL, 0);
+
+	/* Prepare CP spool restore command */
+	n = sprintf(info->spool_restore_cmd, "SPOOL %X", info->devno);
+
+	/* Save the CLASS value if required */
+	if (info->spool_class_specified) {
+		cl = resp[13];
+		n += sprintf(info->spool_restore_cmd + n, " CL %c", cl);
+	}
+
+	/* Save FORM value if required */
+	if (info->spool_form_specified) {
+		tmp = strstr(resp, "FORM ");
+		if (tmp == NULL)
+			ERR_EXIT("Could not retrieve value for the FORM "
+				 "spooling option\n");
+		strncpy_graph(value, tmp + 5, 8);
+		n += sprintf(info->spool_restore_cmd + n, " FORM %s", value);
+	}
+
+	/* Save DEST value if required */
+	if (info->spool_dest_specified) {
+		tmp = strstr(resp, "DEST ");
+		if (tmp == NULL)
+			ERR_EXIT("Could not retrieve value for the DEST "
+				 "spooling option\n");
+		strncpy_graph(value, tmp + 5, 8);
+		n += sprintf(info->spool_restore_cmd + n, " DEST %s", value);
+	}
+
+	/* Save DIST value if required */
+	if (info->spool_dist_specified) {
+		tmp = strstr(resp, "DIST ");
+		if (tmp == NULL)
+			ERR_EXIT("Could not retrieve value for the DIST "
+				 "spooling option\n");
+		strncpy_graph(value, tmp + 5, 8);
+		n += sprintf(info->spool_restore_cmd + n, " DIST %s", value);
+	}
+
+	free(resp);
+	++info->spool_restore_needed;
+}
+
+/*
+ * Restore saved spooling options for a ur device
+ */
+static void restore_spool_options(struct vmur *info)
+{
+	if (!info->spool_restore_needed)
+		return;
+
+	cpcmd(info->spool_restore_cmd, NULL, NULL, 0);
+	--info->spool_restore_needed;
+}
+
+/*
+ * Returns non-zero if spool options have to be saved, changed, and restored,
+ * otherwise zero is returned.
+ */
+static int require_spool_setup(struct vmur *info)
+{
+	return !!(info->spool_class_specified ||
+		  info->spool_form_specified ||
+		  info->spool_dest_specified ||
+		  info->spool_dist_specified);
+}
+
+/*
+ * Setup spooling options for a ur device
+ */
+static void setup_spool_options(struct vmur *info)
+{
+	char cmd[MAXCMDLEN];
+	int n, rc;
+
+	/*
+	 * Check if spool options must be changed.  If so, save the current
+	 * spool option values and restore them at program exit.
+	 */
+	if (!require_spool_setup(info))
+		return;
+
+	/* Save spool options */
+	save_spool_options(info);
+
+	/* Change spool options */
+	n = sprintf(cmd, "SPOOL %X", info->devno);
+	if (info->spool_class_specified)
+		n += sprintf(cmd + n, " CLASS %c", info->spool_class);
+	if (info->spool_form_specified)
+		n += sprintf(cmd + n, " FORM %s", info->spool_form);
+	if (info->spool_dest_specified)
+		n += sprintf(cmd + n, " DEST %s", info->spool_dest);
+	if (info->spool_dist_specified)
+		n += sprintf(cmd + n, " DIST %s", info->spool_dist);
+
+	cpcmd(cmd, NULL, &rc, 0);
+	if (rc)
+		ERR_EXIT("Could not set spooling options (rc=%i)\n", rc);
+}
+
 /*
  * Setup and check ur device
  */
@@ -482,6 +630,13 @@ static void setup_ur_device(struct vmur *info)
 	dev_t node_dev;
 	int rc;
 
+	/*
+	 * Few vmur commands do not require a particular device node and,
+	 * therefore, no device setup is required.
+	 */
+	if (!strlen(info->devnode))
+		return;
+
 	node_dev = get_node_dev(info->devnode);
 	rc = get_driver_major(&driver_major);
 	if ((rc == 0) && (driver_major != major(node_dev)))
@@ -497,6 +652,7 @@ static void init_info(struct vmur *info)
 {
 	memset(info, 0, sizeof(struct vmur));
 	strcpy(info->queue, "rdr");
+	info->lock_fd = -1;
 }
 
 /*
@@ -567,6 +723,9 @@ static void set_queue(struct vmur *info, char *queue)
 	return;
 }
 
+/*
+ * Set block mode and the separator and padding byte
+ */
 static void set_blocked(struct vmur *info, char *blocked)
 {
 	if (sscanf(blocked, "0x%x,0x%x", &info->blocked_separator,
@@ -583,6 +742,22 @@ fail:
 		 "'0xSS,0xPP'.\n");
 }
 
+/*
+ * Set spool class value
+ */
+static void set_spool_class(struct vmur *info, const char *val, int is_rdr)
+{
+	char cl = val[0];
+
+	if (strlen(val) > 1 || (!isalnum(cl) && cl != '*'))
+		ERR_EXIT("Class must be one of A through Z, 0 through 9, "
+			 "or an asterisk (*)\n");
+	if (cl == '*' && !is_rdr)
+		ERR_EXIT("The asterisk (*) class is only valid for readers\n");
+	info->spool_class = toupper(cl);
+	++info->spool_class_specified;
+}
+
 /*
  * Parse the command line: General options
  */
@@ -620,9 +795,10 @@ static void parse_opts_receive(struct vmur *info, int argc, char *argv[])
 		{ "convert",     no_argument,       NULL, 'c'},
 		{ "device",      required_argument, NULL, 'd'},
 		{ "blocked",     required_argument, NULL, 'b'},
+		{ "class",       required_argument, NULL, 'C'},
 		{ 0,             0,                 0,    0  }
 	};
-	static const char option_string[] = "vhtOfHcd:b:";
+	static const char option_string[] = "vhtOfHcd:b:C:";
 
 	strcpy(info->devnode, VMRDR_DEVICE_NODE);
 	while (1) {
@@ -655,6 +831,9 @@ static void parse_opts_receive(struct vmur *info, int argc, char *argv[])
 		case 'c':
 			++info->convert_specified;
 			break;
+		case 'C':
+			set_spool_class(info, optarg, 1);
+			break;
 		default:
 			std_usage_exit();
 		}
@@ -671,13 +850,16 @@ static void parse_opts_receive(struct vmur *info, int argc, char *argv[])
 	CHECK_SPEC_MAX(info->hold_specified, 1, "hold");
 	CHECK_SPEC_MAX(info->stdout_specified, 1, "stdout");
 	CHECK_SPEC_MAX(info->convert_specified, 1, "convert");
+	CHECK_SPEC_MAX(info->spool_class_specified, 1, "class");
 
 	if (info->stdout_specified && info->file_name_specified)
-		ERR_EXIT("File name not allowed, when --stdout specifed!\n");
+		ERR_EXIT("File name not allowed, when --stdout specified!\n");
 	if (info->blocked_specified + info->text_specified +
 	    info->convert_specified > 1)
 		ERR_EXIT("Conflicting options: -b, -t and -c are mutually "
 			 "exclusive.\n");
+	if (!info->spool_class_specified)
+		set_spool_class(info, "*", 1);
 }
 
 /*
@@ -799,9 +981,13 @@ static void parse_opts_punch_print(struct vmur *info, int argc, char *argv[])
 		{ "device",      required_argument, NULL, 's'},
 		{ "blocked",     required_argument, NULL, 'b'},
 		{ "name",        required_argument, NULL, 'N'},
+		{ "class",       required_argument, NULL, 'C'},
+		{ "dest",        required_argument, NULL, 'D'},
+		{ "form",        required_argument, NULL, 'F'},
+		{ "dist",	 required_argument, NULL, 'I'},
 		{ 0,             0,                 0,    0  }
 	};
-	static const char option_string[] = "vhtrfu:n:d:b:N:";
+	static const char option_string[] = "vhtrfu:n:d:b:N:C:";
 
 	if (info->action == PUNCH) {
 		strcpy(info->devnode, VMPUN_DEVICE_NODE);
@@ -852,6 +1038,30 @@ static void parse_opts_punch_print(struct vmur *info, int argc, char *argv[])
 			else
 				strcpy(info->node, optarg);
 			break;
+		case 'C':
+			set_spool_class(info, optarg, 0);
+			break;
+		case 'D':
+			++info->spool_dest_specified;
+			if (invalid_operand(optarg))
+				ERR_EXIT("Invalid destination: %s\n", optarg);
+			else
+				strcpy(info->spool_dest, optarg);
+			break;
+		case 'F':
+			++info->spool_form_specified;
+			if (invalid_operand(optarg))
+				ERR_EXIT("Invalid form: %s\n", optarg);
+			else
+				strcpy(info->spool_form, optarg);
+			break;
+		case 'I':
+			++info->spool_dist_specified;
+			if (invalid_operand(optarg))
+				ERR_EXIT("Invalid distribution code: %s\n", optarg);
+			else
+				strcpy(info->spool_dist, optarg);
+			break;
 		default:
 			std_usage_exit();
 		}
@@ -865,6 +1075,10 @@ static void parse_opts_punch_print(struct vmur *info, int argc, char *argv[])
 	CHECK_SPEC_MAX(info->user_specified, 1, "user");
 	CHECK_SPEC_MAX(info->node_specified, 1, "node");
 	CHECK_SPEC_MAX(info->blocked_specified, 1, "blocked");
+	CHECK_SPEC_MAX(info->spool_class_specified, 1, "class");
+	CHECK_SPEC_MAX(info->spool_form_specified, 1, "form");
+	CHECK_SPEC_MAX(info->spool_dest_specified, 1, "dest");
+	CHECK_SPEC_MAX(info->spool_dist_specified, 1, "dist");
 
 	if (info->user_specified && !info->rdr_specified)
 		ERR_EXIT("--user without --rdr specified\n");
@@ -900,9 +1114,12 @@ static void parse_opts_purge(struct vmur *info, int argc, char *argv[])
 		{ "help",        no_argument,       NULL, 'h'},
 		{ "force",       no_argument,       NULL, 'f'},
 		{ "queue",       no_argument,       NULL, 'q'},
+		{ "class",       required_argument, NULL, 'C'},
+		{ "dest",        required_argument, NULL, 'D'},
+		{ "form",        required_argument, NULL, 'F'},
 		{ 0,             0,                 0,    0  }
 	};
-	static const char option_string[] = "fvhq:";
+	static const char option_string[] = "fvhq:C:";
 
 	while (1) {
 		opt = getopt_long(argc, argv, option_string,
@@ -918,12 +1135,32 @@ static void parse_opts_purge(struct vmur *info, int argc, char *argv[])
 			++info->queue_specified;
 			set_queue(info, optarg);
 			break;
+		case 'C':
+			set_spool_class(info, optarg, 0);
+			break;
+		case 'D':
+			++info->spool_dest_specified;
+			if (invalid_operand(optarg))
+				ERR_EXIT("Invalid destination: %s\n", optarg);
+			else
+				strcpy(info->spool_dest, optarg);
+			break;
+		case 'F':
+			++info->spool_form_specified;
+			if (invalid_operand(optarg))
+				ERR_EXIT("Invalid form: %s\n", optarg);
+			else
+				strcpy(info->spool_form, optarg);
+			break;
 		default:
 			std_usage_exit();
 		}
 	}
 	CHECK_SPEC_MAX(info->force_specified, 1, "force");
 	CHECK_SPEC_MAX(info->queue_specified, 1, "queue");
+	CHECK_SPEC_MAX(info->spool_class_specified, 1, "class");
+	CHECK_SPEC_MAX(info->spool_form_specified, 1, "form");
+	CHECK_SPEC_MAX(info->spool_dest_specified, 1, "dest");
 	set_spoolid(info, argv, argc, optind + 1, 0);
 }
 
@@ -1182,7 +1419,7 @@ static int check_class(struct vmur *info)
 }
 
 /*
- * Get filename for spoolid from reader
+ * Get file name for spoolid from reader
  */
 static int get_filename_from_reader(struct vmur *info)
 {
@@ -1221,16 +1458,15 @@ static int get_filename_from_reader(struct vmur *info)
  */
 static void acquire_lock(struct vmur *info)
 {
-	int fd;
 	char failed_action[10] = {};
 
-	fd = open(LOCK_FILE, O_RDONLY | O_CREAT, S_IRUSR);
-	if (fd == -1) {
+	info->lock_fd = open(LOCK_FILE, O_RDONLY | O_CREAT, S_IRUSR);
+	if (info->lock_fd == -1) {
 		ERR("WARNING: Unable to open lock file %s, continuing "
 		    "without any serialization.\n", LOCK_FILE);
 		return;
 	}
-	if (flock(fd, LOCK_EX | LOCK_NB) == -1) {
+	if (flock(info->lock_fd, LOCK_EX | LOCK_NB) == -1) {
 		switch (info->action) {
 		case RECEIVE:
 			strcpy(failed_action, "received");
@@ -1256,6 +1492,16 @@ static void acquire_lock(struct vmur *info)
 	}
 }
 
+/*
+ * Release lock and close lock file
+ */
+static void release_lock(struct vmur *info)
+{
+	flock(info->lock_fd, LOCK_UN);
+	close(info->lock_fd);
+	info->lock_fd = -1;
+}
+
 /*
  * Check if file already exists. If yes, ask if it should be overwritten.
  */
@@ -1322,7 +1568,7 @@ enum spoolfile_fmt get_spoolfile_fmt(struct vmur *info,
 }
 
 /*
- * Convert record for texmode: Do EBCDIC->ASCII translation
+ * Convert record for text mode: Do EBCDIC->ASCII translation
  */
 static int convert_text(struct vmur *info, struct splink_record *rec,
 			char **out_ptr)
@@ -1482,6 +1728,15 @@ int write_vmdump(struct vmur *info, struct splink_page *sfdata, int count,
 	return 0;
 }
 
+/*
+ * Clean up and restore spool options
+ */
+static void cleanup_atexit_fn(void)
+{
+	restore_spool_options(&vmur_info);
+	release_lock(&vmur_info);
+}
+
 /*
  * Close VM virtual reader in case of a signal e.g. CTRL-C
 */
@@ -1489,6 +1744,7 @@ static void ur_receive_sig_handler(int UNUSED(sig), siginfo_t *UNUSED(sip),
 				   void *UNUSED(p))
 {
 	close_reader(&vmur_info, "HOLD");
+	cleanup_atexit_fn();
 	ERR_EXIT("Operation terminated, spool file received incompletely.\n");
 }
 
@@ -1503,11 +1759,8 @@ static void ur_receive(struct vmur *info)
 	int rc;
 
 	if (check_class(info))
-		ERR_EXIT("Reader device class does not match spool file "
-			 "class.\nIssue CP command 'SPOOL %X CLASS *' to "
-			 "enable %X for any spool file class.\n",
-			 info->devno, info->devno);
-	acquire_lock(info);
+		ERR_EXIT("Reader device class does not match the specified "
+			 "spool file class\n");
 	close_reader(info, "HOLD");
 	order_change_reader_file(info);
 
@@ -1525,7 +1778,7 @@ static void ur_receive(struct vmur *info)
 		check_overwrite(info);
 	}
 
-	/* Read first block and check spoolfile format */
+	/* Read first block and check spool file format */
 
 	count = read(fhi, &sfdata, READ_BLOCKS * sizeof(sfdata[0]));
 	if (count == -1) {
@@ -1739,6 +1992,7 @@ static void ur_write_sig_handler(int UNUSED(sig), siginfo_t *UNUSED(sip),
 				 void *UNUSED(p))
 {
 	close_ur_device_purge(&vmur_info);
+	cleanup_atexit_fn();
 	ERR_EXIT("Operation terminated, no spool file created.\n");
 }
 
@@ -1897,8 +2151,6 @@ static void ur_write(struct vmur *info)
 	char *sfdata;
 	ssize_t count;
 
-	acquire_lock(info);
-
 	/* close punch preventively */
 	close_ur_device_simple(info);
 
@@ -1983,13 +2235,16 @@ static void ur_purge_question(struct vmur *info)
 	if (info->force_specified)
 		return;
 
-	if (info->spoolid_specified)
-		fprintf(stderr, "%s: purge %s %s? ", prog_name, info->queue,
-		       info->spoolid);
-	else
-		fprintf(stderr, "%s: purge all %s files? ", prog_name,
-			info->queue);
+	fprintf(stderr, "%s: purge selected %s file(s)? ", prog_name,
+		info->queue);
+	/*
+	 * Release the vmur session lock while waiting for user input.  It is
+	 * safe to release the lock here, because the ur_purge operation does
+	 * not modify spool options.
+	 */
+	release_lock(info);
 	str = fgets(buf, sizeof(buf), stdin);
+	acquire_lock(info);
 	if (!str)
 		exit(1);
 	if (strcasecmp(buf, "y\n") == 0)
@@ -2005,13 +2260,29 @@ static void ur_purge_question(struct vmur *info)
 static int ur_purge(struct vmur *info)
 {
 	char *buf, cmd[MAXCMDLEN];
+	int n, m;
 
 	ur_purge_question(info);
+
+	/* Prepare the CP PURGE command */
+	n = m = sprintf(cmd, "PURGE * %s", info->queue);
+
+	/* Add selection criteria to match spool files */
 	if (info->spoolid_specified)
-		sprintf(cmd, "PURGE * %s %s", info->queue, info->spoolid);
-	else
-		sprintf(cmd, "PURGE * %s ALL", info->queue);
-	acquire_lock(info);
+		n += sprintf(cmd + n, " %s", info->spoolid);
+	if (info->spool_class_specified)
+		n += sprintf(cmd + n, " CLASS %c", info->spool_class);
+	if (info->spool_form_specified)
+		n += sprintf(cmd + n, " FORM %s", info->spool_form);
+	if (info->spool_dest_specified)
+		n += sprintf(cmd + n, " DEST %s", info->spool_dest);
+
+	/* Purge all files if no spoolid or any of the class, form, or dest
+	 * option is specified.
+	 */
+	if (n == m)
+		n += sprintf(cmd + n, " ALL");
+
 	cpcmd(cmd, &buf, NULL, 0);
 	ERR("%s", buf);
 	free(buf);
@@ -2026,7 +2297,6 @@ static int ur_order(struct vmur *info)
 	char cmd[MAXCMDLEN];
 
 	sprintf(cmd, "ORDER * %s %s", info->queue, info->spoolid);
-	acquire_lock(info);
 	cpcmd(cmd, NULL, NULL, 0);
 	return 0;
 }
@@ -2063,18 +2333,29 @@ static void setup_iconv(struct vmur *info, const char *from, const char *to)
 
 int main(int argc, char **argv)
 {
-	/* set name of program */
+	/* Set name of program */
 	prog_name = basename(argv[0]);
 
-	/* set default values */
+	/* Set default values */
 	init_info(&vmur_info);
 
-	/* parse command line options and check syntax */
+	/* Parse command line options and check syntax */
 	parse_opts(&vmur_info, argc, argv);
 
+	/* Register cleanup function */
+	if (atexit(cleanup_atexit_fn))
+		ERR_EXIT("Could not set up vmur session cleanup\n");
+
+	/* Acquire a lock to serialize concurrent vmur invocations */
+	acquire_lock(&vmur_info);
+
+	/* Retrieve ur device number */
+	setup_ur_device(&vmur_info);
+
 	switch (vmur_info.action) {
 	case RECEIVE:
-		setup_ur_device(&vmur_info);
+		/* Setup spool options */
+		setup_spool_options(&vmur_info);
 		if (vmur_info.text_specified)
 			setup_iconv(&vmur_info, EBCDIC_CODE_PAGE,
 				    ASCII_CODE_PAGE);
@@ -2082,10 +2363,11 @@ int main(int argc, char **argv)
 		break;
 	case PUNCH:
 	case PRINT:
+		/* Setup spool options */
+		setup_spool_options(&vmur_info);
 		if (vmur_info.text_specified)
 			setup_iconv(&vmur_info, ASCII_CODE_PAGE,
 				    EBCDIC_CODE_PAGE);
-		setup_ur_device(&vmur_info);
 		ur_write(&vmur_info);
 		break;
 	case PURGE:
