@@ -39,6 +39,7 @@ u64 dfi_live_dump_magic = 0x4c49564544554d50ULL; /* LIVEDUMP */
 struct cpus {
 	struct util_list	list;
 	enum dfi_cpu_content	content;
+	int			fac;
 	unsigned int		cnt;
 };
 
@@ -481,6 +482,22 @@ enum dfi_cpu_content dfi_cpu_content(void)
 	return l.cpus.content;
 }
 
+/*
+ * Add CPU facility
+ */
+void dfi_cpu_content_fac_add(int flags)
+{
+	l.cpus.fac |= flags;
+}
+
+/*
+ * Check CPU facility
+ */
+int dfi_cpu_content_fac_check(int flags)
+{
+	return l.cpus.fac & flags;
+}
+
 /*
  * Set DFI architecture
  */
@@ -760,6 +777,9 @@ void dfi_cpu_64_to_32(struct dfi_cpu_32 *cpu_32, struct dfi_cpu *cpu_64)
  */
 static void lc2cpu_64(struct dfi_cpu *cpu, struct dfi_lowcore_64 *lc)
 {
+	char vx_sa[DFI_VX_SA_SIZE];
+	int i;
+
 	memcpy(&cpu->gprs, lc->gpregs_save_area, sizeof(cpu->gprs));
 	memcpy(&cpu->ctrs, lc->cregs_save_area, sizeof(cpu->ctrs));
 	memcpy(&cpu->acrs, lc->access_regs_save_area, sizeof(cpu->acrs));
@@ -770,6 +790,14 @@ static void lc2cpu_64(struct dfi_cpu *cpu, struct dfi_lowcore_64 *lc)
 	memcpy(&cpu->timer, lc->timer_save_area, sizeof(cpu->timer));
 	memcpy(&cpu->todpreg, &lc->tod_progreg_save_area, sizeof(cpu->todpreg));
 	memcpy(&cpu->todcmp, lc->clock_comp_save_area, sizeof(cpu->todcmp));
+	/* Add VX registers if available */
+	if (!dfi_cpu_lc_has_vx_sa(lc))
+		return;
+	dfi_mem_read(lc->vector_save_area_addr, &vx_sa, sizeof(vx_sa));
+	memcpy(cpu->vxrs_high, &vx_sa[16 * 16], sizeof(cpu->vxrs_high));
+	for (i = 0; i < 16; i++)
+		memcpy(&cpu->vxrs_low[i], &vx_sa[16 * i + 8], sizeof(u64));
+	dfi_cpu_content_fac_add(DFI_CPU_CONTENT_FAC_VX);
 }
 
 /*
@@ -820,6 +848,37 @@ void dfi_cpu_add_from_lc(u32 lc_addr)
 	dfi_cpu_add(cpu);
 }
 
+/*
+ * Check if lowcore has VX registers
+ */
+int dfi_cpu_lc_has_vx_sa(void *_lc)
+{
+	struct dfi_lowcore_64 *lc = _lc;
+
+	if (l.arch == DFI_ARCH_32)
+		return 0;
+	if (lc->vector_save_area_addr == 0)
+		return 0;
+	if (lc->vector_save_area_addr % 1024 != 0)
+		return 0;
+	return 1;
+}
+
+/*
+ * Copy VX registers out of save areas
+ */
+void dfi_cpu_vx_copy(void *buf, struct dfi_cpu *cpu)
+{
+	char *_buf = buf;
+	int i;
+
+	for (i = 0; i < 16; i++) {
+		memcpy(&_buf[i * 16], &cpu->fprs[i], 8);
+		memcpy(&_buf[i * 16 + 8], &cpu->vxrs_low[i], 8);
+	}
+	memcpy(&_buf[16 * 16], &cpu->vxrs_high[0], 16 * 16);
+}
+
 /*
  * Return kdump base
  */
@@ -889,6 +948,7 @@ static void mem_unmap(u64 start, u64 size)
 		}
 free:
 		util_list_remove(&l.mem_virt.chunk_list, mem_chunk);
+		l.mem_virt.chunk_cnt--;
 		if (mem_chunk->data && mem_chunk->free_fn)
 			mem_chunk->free_fn(mem_chunk->data);
 		zg_free(mem_chunk);
