@@ -48,7 +48,9 @@ struct dfi_lowcore_32 {
 struct dfi_lowcore_64 {
 	u8	pad_0x0000[0x0084 - 0x0000];	/* 0x0000 */
 	u16	cpu_addr;			/* 0x0084 */
-	u8	pad_0x0086[0x1200 - 0x0086];	/* 0x0086 */
+	u8	pad_0x0086[0x11b0 - 0x0086];	/* 0x0086 */
+	u64	vector_save_area_addr;		/* 0x11b0 */
+	u8	pad_0x11b8[0x1200 - 0x11b8];	/* 0x11b8 */
 	u64	floating_pt_save_area[16];	/* 0x1200 */
 	u64	gpregs_save_area[16];		/* 0x1280 */
 	u32	st_status_fixed_logout[4];	/* 0x1300 */
@@ -73,6 +75,11 @@ static inline u64 dfi_lc_size(enum dfi_arch arch)
 		return 0x1000;
 }
 
+struct dfi_vxrs {
+	u64 low;
+	u64 high;
+};
+
 struct dfi_cpu {
 	struct util_list_node	list;
 	u64		gprs[16];
@@ -85,17 +92,21 @@ struct dfi_cpu {
 	u64		timer;
 	u64		todcmp;
 	u32		todpreg;
+	u64		vxrs_low[16];
+	struct dfi_vxrs	vxrs_high[16];
 };
 
 struct dfi_cpu_32 {
-	u32	gprs[16];
-	u32	ctrs[16];
-	u32	acrs[16];
-	u64	fprs[4];
-	u32	psw[2];
-	u32	prefix;
-	u64	timer;
-	u64	todcmp;
+	u32		gprs[16];
+	u32		ctrs[16];
+	u32		acrs[16];
+	u64		fprs[4];
+	u32		psw[2];
+	u32		prefix;
+	u64		timer;
+	u64		todcmp;
+	u64		vxrs_low[16];
+	struct dfi_vxrs	vxrs_high[16];
 };
 
 extern void dfi_cpu_64_to_32(struct dfi_cpu_32 *cpu_32, struct dfi_cpu *cpu_64);
@@ -110,6 +121,10 @@ enum dfi_cpu_content {
 	DFI_CPU_CONTENT_ALL,	/* Complete register information available */
 };
 
+#define DFI_CPU_CONTENT_FAC_VX	0x00000001
+extern int dfi_cpu_content_fac_check(int falgs);
+extern void dfi_cpu_content_fac_add(int flags);
+
 #define dfi_cpu_iterate(cpu) \
 	util_list_iterate(dfi_cpu_list(), cpu)
 
@@ -122,6 +137,10 @@ extern unsigned int dfi_cpu_cnt(void);
 extern enum dfi_cpu_content dfi_cpu_content(void);
 extern void dfi_cpu_add_from_lc(u32 lc_addr);
 
+#define DFI_VX_SA_SIZE		(32 * 16)
+extern int dfi_cpu_lc_has_vx_sa(void *lc);
+extern void dfi_cpu_vx_copy(void *buf, struct dfi_cpu *cpu);
+
 /*
  * Mem chunk functions and definitions
  */
