@@ -172,6 +172,24 @@ static int nt_s390_prefix_read(struct dfi_cpu *cpu, Elf64_Nhdr *note)
 	return nt_read(note, &cpu->prefix);
 }
 
+/*
+ * Read s390 vxrs_low note
+ */
+static int nt_s390_vxrs_low_read(struct dfi_cpu *cpu, Elf64_Nhdr *note)
+{
+	check_cpu(cpu, "S390_VXRS_LOW");
+	return nt_read(note, &cpu->vxrs_low);
+}
+
+/*
+ * Read s390 vxrs_high note
+ */
+static int nt_s390_vxrs_high_read(struct dfi_cpu *cpu, Elf64_Nhdr *note)
+{
+	check_cpu(cpu, "S390_VXRS_HIGH");
+	return nt_read(note, &cpu->vxrs_high);
+}
+
 /*
  * Add all notes for notes phdr
  */
@@ -219,6 +237,16 @@ static int pt_notes_add(Elf64_Phdr *phdr)
 			if (nt_s390_prefix_read(cpu_current, &note))
 				return -EINVAL;
 			break;
+		case NT_S390_VXRS_LOW:
+			if (nt_s390_vxrs_low_read(cpu_current, &note))
+				return -EINVAL;
+			dfi_cpu_content_fac_add(DFI_CPU_CONTENT_FAC_VX);
+			break;
+		case NT_S390_VXRS_HIGH:
+			if (nt_s390_vxrs_high_read(cpu_current, &note))
+				return -EINVAL;
+			dfi_cpu_content_fac_add(DFI_CPU_CONTENT_FAC_VX);
+			break;
 		default:
 			if (nt_skip(&note))
 				return -EINVAL;
