@@ -10,7 +10,7 @@
 #ifndef DFO_H
 #define DFO_H
 
-#include "list.h"
+#include "util.h"
 #include "zg.h"
 
 struct dfo_chunk;
@@ -19,7 +19,7 @@ typedef void (*dfo_chunk_read_fn)(struct dfo_chunk *chunk, u64 off,
 				    void *buf, u64 cnt);
 
 struct dfo_chunk {
-	struct list		list;
+	struct util_list_node	list;
 	u64			start;
 	u64			end;
 	u64			size;
