@@ -103,18 +103,49 @@ static void dfo_s390_dump_chunk_lc_fn(struct dfo_chunk *dump_chunk,
 	memcpy(buf, &lc[off], cnt);
 }
 
+/*
+ * Copy register set to prefix page
+ */
+static void dfo_s390_dump_chunk_vx_fn(struct dfo_chunk *dump_chunk,
+				      u64 off, void *buf, u64 cnt)
+{
+	char *vx_regs = dump_chunk->data;
+
+	memcpy(buf, &vx_regs[off], cnt);
+}
+
 /*
  * Add register set to dump layout. We copy the register sets to the
  * lowcore pages.
  */
 static void add_cpu_to_dfo(struct dfi_cpu *cpu)
 {
+	struct dfi_lowcore_64 lc;
+	void *vx_regs;
+
 	if (dfi_cpu_content() != DFI_CPU_CONTENT_ALL)
 		return;
-
+	if (!dfi_mem_range_valid(cpu->prefix, dfi_lc_size(dfi_arch()))) {
+		STDERR("Info: Could not read CPU prefix page: %x\n",
+		       cpu->prefix);
+		return;
+	}
+	/* Add lowcore to memory */
 	dfo_chunk_add(cpu->prefix + DF_S390_HDR_SIZE,
 		      dfi_lc_size(dfi_arch()), cpu,
 		      dfo_s390_dump_chunk_lc_fn);
+	/* Add VX save area to memory */
+	if (dfi_arch() != DFI_ARCH_64)
+		return;
+	if (!dfi_cpu_content_fac_check(DFI_CPU_CONTENT_FAC_VX))
+		return;
+	dfi_mem_read(cpu->prefix, &lc, sizeof(lc));
+	if (!dfi_cpu_lc_has_vx_sa(&lc))
+		return;
+	vx_regs = zg_alloc(DFI_VX_SA_SIZE);
+	dfi_cpu_vx_copy(vx_regs, cpu);
+	dfo_chunk_add(lc.vector_save_area_addr + DF_S390_HDR_SIZE,
+		      DFI_VX_SA_SIZE, vx_regs, dfo_s390_dump_chunk_vx_fn);
 }
 
 /*
