@@ -57,10 +57,7 @@ extern struct zgetdump_globals {
 extern void opts_parse(int argc, char *argv[]);
 extern int stdout_write_dump(void);
 
-#ifndef WITHOUT_FUSE
-extern int zfuse_mount_dump(void);
-extern void zfuse_umount(void);
-#else
+#if HAVE_FUSE == 0
 static inline int zfuse_mount_dump(void)
 {
 	ERR_EXIT("Program compiled without fuse support");
@@ -69,6 +66,9 @@ static inline void zfuse_umount(void)
 {
 	ERR_EXIT("Program compiled without fuse support");
 }
+#else
+int zfuse_mount_dump(void);
+void zfuse_umount(void);
 #endif
 
 /*
