@@ -348,7 +348,7 @@ static __s32 position_in_file(FILE *fp, struct message *msg,
 			return -1;
 		cum_size += next_msg_length;
 		fseek(fp, next_msg_length, SEEK_CUR);
-		vverbose_msg("    read msg, cum_size=%d, needed=%d\n", cum_size, get_total_msg_size(msg));
+		vverbose_msg("    read msg, cum_size=%ld, needed=%d\n", cum_size, get_total_msg_size(msg));
 	}
 	if (cum_size - get_total_msg_size(msg) > 0
 	    && cum_size - get_total_msg_size(msg) < 8) {
