@@ -418,13 +418,13 @@ void VirtAdapterPrinter::print_virt_adpt(FILE *fp, __u32 devno,
 					int *rc)
 {
 	if (m_csv)
-		fprintf(fp, "%x,0.0.%04x,",
+		fprintf(fp, "%x,%x.%x.%04x,",
 			       m_cfg->get_chpid_by_devno(devno, rc),
-			       devno);
+			       ZIOREP_BUSID_UNPACKED(devno));
 	else
-		fprintf(fp, "%3x/0.0.%04x",
+		fprintf(fp, "%3x/%x.%x.%04x",
 			       m_cfg->get_chpid_by_devno(devno, rc),
-			       devno);
+			       ZIOREP_BUSID_UNPACKED(devno));
 }
 
 void VirtAdapterPrinter::print_queue_fill(FILE *fp,
@@ -764,7 +764,7 @@ void TrafficPrinter::print_device_chpid(FILE *fp, __u32 chpid)
 
 void TrafficPrinter::print_device_devno(FILE *fp, __u32 devno)
 {
-	fprintf(fp, "0.0.%04x", devno);
+	fprintf(fp, "%x.%x.%04x", ZIOREP_BUSID_UNPACKED(devno));
 }
 
 void TrafficPrinter::print_device_mp_mm(FILE *fp, __u32 mp_mm,
