@@ -425,12 +425,12 @@ int print_summary_report(FILE *fp, char *filename, ConfigReader &cfg)
 	for (list<__u32>::const_iterator i = host_ids.begin();
 	      i != host_ids.end(); ++i) {
 		if (first) {
-			frmt = "HBA/CHPID:        0.0.%04x/%x\n";
+			frmt = "HBA/CHPID:        %x.%x.%04x/%x\n";
 			first = 0;
 		}
 		else
-			frmt = "                  0.0.%04x/%x\n";
-		rc += fprintf(fp, frmt, cfg.get_devno_by_host_id(*i, &lrc),
+			frmt = "                  %x.%x.%04x/%x\n";
+		rc += fprintf(fp, frmt, ZIOREP_BUSID_UNPACKED(cfg.get_devno_by_host_id(*i, &lrc)),
 			      cfg.get_chpid_by_host_id(*i, &lrc));
 		if (lrc)
 			return -1;
