@@ -18,6 +18,7 @@
 
 
 int install_bootloader(const char* device, disk_blockptr_t* program_table,
+		       disk_blockptr_t* scsi_dump_sb_blockptr,
 		       disk_blockptr_t* stage2_data, blocknum_t stage2_count,
 		       struct disk_info* info, struct job_data* job);
 int install_tapeloader(const char* device, const char* image,
@@ -29,4 +30,13 @@ int install_dump(const char* device, struct job_target_data* target,
 int install_mvdump(char* const device[], struct job_target_data* target,
 		   int device_count, uint64_t mem, uint8_t force);
 
+int install_fba_stage1b(int fd, disk_blockptr_t **stage1b_list,
+			blocknum_t *stage1b_count, disk_blockptr_t *stage2_list,
+			blocknum_t stage2_count, struct disk_info *info);
+int install_eckd_stage1b(int fd, disk_blockptr_t **stage1b_list,
+			 blocknum_t *stage1b_count,
+			 disk_blockptr_t *stage2_list,
+			 blocknum_t stage2_count, struct disk_info *info);
+int rewind_tape(int fd);
+
 #endif /* INSTALL_H */
