@@ -25,14 +25,18 @@ struct misc_file_buffer {
 
 
 void* misc_malloc(size_t size);
+int misc_asprintf(char **out, const char *fmt, ...);
 void* misc_calloc(size_t n, size_t size);
 char* misc_strdup(const char* s);
+int misc_open_exclusive(const char* filename);
 int misc_read(int fd, void* buffer, size_t count);
 int misc_read_file(const char* filename, char** buffer, size_t* size,
 		   int nil_terminate);
 int misc_read_special_file(const char* filename, char** buffer, size_t* size,
 			   int nil_terminate);
 int misc_write(int fd, const void* data, size_t count);
+int misc_pwrite(int fd, void *buf, size_t size, off_t off);
+int misc_seek(int fd, off_t off);
 int misc_get_file_buffer(const char* filename,
 			 struct misc_file_buffer* buffer);
 void misc_free_file_buffer(struct misc_file_buffer* file);
@@ -44,5 +48,10 @@ void misc_free_temp_dev(char* device);
 int misc_check_writable_directory(const char* directory);
 int misc_check_readable_file(const char* filename);
 int misc_check_writable_device(const char* devno, int blockdev, int chardev);
+void misc_ebcdic_to_ascii(unsigned char *from, unsigned char *to);
+void misc_ascii_to_ebcdic(unsigned char *from, unsigned char *to);
 
+#define MAX(x, y) ((x) > (y) ? (x) : (y))
+#define ROUNDUP(x, y) ((((x) + ((y) - 1)) / (y)) * (y))
+#define DIV_ROUND_UP(n, d) (((n) + (d) - 1) / (d))
 #endif /* not MISC_H */
