@@ -18,6 +18,7 @@
 
 #include "error.h"
 #include "misc.h"
+#include "bootmap.h"
 
 /* Include declarations for boot_data symbols. */
 #include "../boot/data.h"
@@ -25,41 +26,56 @@
 #define DATA_SIZE(x)	((size_t) (&_binary_##x##_bin_size))
 #define DATA_ADDR(x)	(&_binary_##x##_bin_start)
 
-#define STAGE2_MAX_SIZE		4096
+#define STAGE2_MAX_SIZE		0x3000
+#define STAGE1B_LOAD_ADDR	0xe000
+#define CCW_FLAG_CC		0x40
+#define CCW_FLAG_SLI		0x20
+#define FBA_BLK_SIZE		512
 
+static struct boot_ccw0 tic_to_stage1b = {
+	.cmd = 0x08, /* tic */
+	.address_lo = STAGE1B_LOAD_ADDR,
+};
 
 /* Check sizes of internal objects. Return 0 if everything is correct,
  * non-zero otherwise. */
 int
 boot_check_data(void)
 {
-	if (DATA_SIZE(fba0) !=
-	    sizeof(struct boot_fba_stage0)) {
-		error_reason("Size mismatch of stage 0 loader for disks with "
-			     "FBA layout");
+	if (DATA_SIZE(fba0) != sizeof(struct boot_fba_stage0)) {
+		error_reason("Size mismatch of FBA stage 0 loader");
 		return -1;
 	}
-	if (DATA_SIZE(eckd0) !=
-	    sizeof(struct boot_eckd_stage0)) {
-		error_reason("Size mismatch of stage 0 loader for disks with "
-			     "ECKD layout");
+	if (DATA_SIZE(fba1b) != sizeof(struct boot_fba_stage1b)) {
+		error_reason("Size mismatch of FBA stage 1b loader");
 		return -1;
 	}
-	if (DATA_SIZE(eckd1a) !=
-	    sizeof(struct boot_eckd_classic_stage1)) {
-		error_reason("Size mismatch of stage 1 loader for disks with "
-			     "ECKD classic layout");
+	if (DATA_SIZE(eckd0_ldl) !=
+	    sizeof(struct boot_eckd_ldl_stage0)) {
+		error_reason("Size mismatch of ECKD LDL stage 0 loader");
 		return -1;
 	}
-	if (DATA_SIZE(eckd1b) !=
-	    sizeof(struct boot_eckd_compatible_stage1)) {
-		error_reason("Size mismatch of stage 1 loader for disks with "
-			     "ECKD compatible layout");
+	if (DATA_SIZE(eckd0_cdl) != sizeof(struct boot_eckd_cdl_stage0)) {
+		error_reason("Size mismatch of ECKD CDL stage 0 loader");
+		return -1;
+	}
+	if (DATA_SIZE(eckd1) != sizeof(struct boot_eckd_stage1)) {
+		error_reason("Size mismatch of ECKD stage 1 loader");
+		return -1;
+	}
+	if (DATA_SIZE(eckd1b) != sizeof(struct boot_eckd_stage1b)) {
+		error_reason("Size mismatch of ECKD stage 1b loader");
 		return -1;
 	}
 	return 0;
 }
 
+/* Export stage 3 size for partition dump with dump kernel */
+size_t
+get_stage3_size()
+{
+	return DATA_SIZE(stage3);
+}
 
 /* Create a stage 3 loader in memory.
  * Upon success, return 0 and set BUFFER to point to the data buffer and set
@@ -67,7 +83,7 @@ boot_check_data(void)
 int
 boot_get_stage3(void** buffer, size_t* bytecount, address_t parm_addr,
 		address_t initrd_addr, size_t initrd_len, address_t image_addr,
-		int extra_parm)
+		int extra_parm, uint16_t flags)
 {
 	struct boot_stage3_params params;
 	void* data;
@@ -85,8 +101,9 @@ boot_get_stage3(void** buffer, size_t* bytecount, address_t parm_addr,
 	params.parm_addr = (uint64_t) parm_addr;
 	params.initrd_addr = (uint64_t) initrd_addr;
 	params.initrd_len = (uint64_t) initrd_len;
-	params.load_psw = (uint64_t) (image_addr | PSW_LOAD);
+	params.load_psw = (uint64_t)(image_addr | PSW_LOAD);
 	params.extra_parm = (uint64_t) extra_parm;
+	params.flags = flags;
 	/* Initialize buffer */
 	memcpy(data, DATA_ADDR(stage3), DATA_SIZE(stage3));
 	memcpy(data, &params, sizeof(struct boot_stage3_params));
@@ -95,150 +112,124 @@ boot_get_stage3(void** buffer, size_t* bytecount, address_t parm_addr,
 	return 0;
 }
 
-
-#define FBA_FLAG_CC 0x0000000040000000LL
-
 int
-boot_init_fba_stage0(struct boot_fba_stage0* stage0,
-		     disk_blockptr_t* stage2_list, blocknum_t stage2_count)
+boot_init_fba_stage0(struct boot_fba_stage0 *stage0,
+		     disk_blockptr_t *stage1b_list, blocknum_t stage1b_count)
 {
 	blocknum_t i;
 
 	/* Initialize stage 0 data */
-	memcpy(stage0, DATA_ADDR(fba0), sizeof(struct boot_fba_stage0));
+	memcpy(stage0, DATA_ADDR(fba0), sizeof(*stage0));
 	/* Fill in blocklist for stage 2 loader */
-	if (stage2_count > 16) {
-		error_reason("Not enough room for FBA stage 2 loader "
-			     "(try larger block size)");
+	if (stage1b_count > STAGE1B_BLK_CNT_MAX) {
+		error_reason("Not enough room for FBA stage 1b loader");
 		return -1;
 	}
-	for (i=0; i < stage2_count; i++) {
+	for (i = 0; i < stage1b_count; i++) {
 		stage0->locdata[i].blocknr =
+			(uint32_t) stage1b_list[i].linear.block;
+		stage0->locread[i].read.address_lo =
+			STAGE1B_LOAD_ADDR + i * FBA_BLK_SIZE;
+	}
+	/* Terminate CCW chain: Tic to stage 1b */
+	memcpy(&stage0->locread[i], &tic_to_stage1b, sizeof(tic_to_stage1b));
+	return 0;
+}
+
+void
+boot_init_eckd_ldl_stage0(struct boot_eckd_ldl_stage0 *stage0)
+{
+	memcpy(stage0, DATA_ADDR(eckd0_ldl), sizeof(*stage0));
+	/* Fill in size of stage 1 plus stage 0 loader */
+	stage0->read_r1.count = sizeof(struct boot_eckd_stage1) +
+		sizeof(struct boot_eckd_ldl_stage0);
+}
+
+void
+boot_init_eckd_cdl_stage0(struct boot_eckd_cdl_stage0 *stage0)
+{
+	memcpy(stage0, DATA_ADDR(eckd0_cdl), sizeof(*stage0));
+	/* Fill in size of stage 1 loader */
+	stage0->read.count = sizeof(struct boot_eckd_stage1);
+}
+
+int
+boot_init_eckd_stage1(struct boot_eckd_stage1 *stage1,
+		      disk_blockptr_t *stage1b_list, blocknum_t stage1b_count)
+{
+	blocknum_t i;
+
+	memcpy(stage1, DATA_ADDR(eckd1), sizeof(*stage1));
+	/* Fill in blocklist for stage 1b  loader */
+	if (stage1b_count > STAGE1B_BLK_CNT_MAX) {
+		error_reason("Not enough room for ECKD stage 1b loader "
+			     "(try larger block size)");
+		return -1;
+	}
+	for (i = 0; i < stage1b_count; i++) {
+		stage1->ssrt[i].read.count = stage1b_list[i].chs.size;
+		stage1->seek[i].cyl = stage1b_list[i].chs.cyl;
+		stage1->seek[i].head = stage1b_list[i].chs.head |
+			((stage1b_list[i].chs.cyl >> 12) & 0xfff0);
+		stage1->seek[i].sec = stage1b_list[i].chs.sec;
+		stage1->ssrt[i].read.address_lo =
+			STAGE1B_LOAD_ADDR + i * stage1b_list[i].chs.size;
+		stage1->ssrt[i].read.flags = CCW_FLAG_CC | CCW_FLAG_SLI;
+	}
+	/* Terminate CCW chain: Tic to stage 1b */
+	memcpy(&stage1->ssrt[i], &tic_to_stage1b, sizeof(tic_to_stage1b));
+	return 0;
+}
+
+int
+boot_init_fba_stage1b(struct boot_fba_stage1b *stage1b,
+		      disk_blockptr_t *stage2_list, blocknum_t stage2_count)
+{
+	blocknum_t i;
+
+	memcpy(stage1b, DATA_ADDR(fba1b), sizeof(*stage1b));
+	if (stage2_count > STAGE2_BLK_CNT_MAX) {
+		error_reason("Not enough room for FBA stage 2 loader");
+		return -1;
+	}
+	for (i = 0; i < stage2_count; i++) {
+		stage1b->locdata[i].blocknr =
 			(uint32_t) stage2_list[i].linear.block;
+		stage1b->locread[i].read.address_lo =
+			ZIPL_STAGE2_LOAD_ADDRESS + i * FBA_BLK_SIZE;
 	}
 	/* Terminate CCW chain */
-	stage0->locread[i - 1].read &= ~FBA_FLAG_CC;
+	stage1b->locread[i - 1].read.flags &= ~CCW_FLAG_CC;
 	return 0;
 }
 
-
-void
-boot_init_eckd_classic_stage0(struct boot_eckd_stage0* stage0)
-{
-	memcpy(stage0, DATA_ADDR(eckd0), sizeof(struct boot_eckd_stage0));
-	/* Fill in size of stage 1 loader */
-	stage0->read.count = sizeof(struct boot_eckd_classic_stage1);
-}
-
-
-void
-boot_init_eckd_compatible_stage0(struct boot_eckd_stage0* stage0)
-{
-	memcpy(stage0, DATA_ADDR(eckd0), sizeof(struct boot_eckd_stage0));
-	/* Fill in size of stage 1 loader */
-	stage0->read.count = sizeof(struct boot_eckd_compatible_stage1);
-}
-
-
-#define ECKD_CCW_FLAG_CC	0x40
-#define ECKD_CCW_FLAG_SLI	0x20
-
 int
-boot_init_eckd_classic_stage1(struct boot_eckd_classic_stage1* stage1,
-		     disk_blockptr_t* stage2_list, blocknum_t stage2_count)
+boot_init_eckd_stage1b(struct boot_eckd_stage1b *stage1b,
+		       disk_blockptr_t *stage2_list, blocknum_t stage2_count)
 {
 	blocknum_t i;
 
-	memcpy(stage1, DATA_ADDR(eckd1a),
-	       sizeof(struct boot_eckd_classic_stage1));
-	/* Fill in blocklist for stage 2 loader */
-	if (stage2_count > 8) {
+	memcpy(stage1b, DATA_ADDR(eckd1b), sizeof(*stage1b));
+	if (stage2_count > STAGE2_BLK_CNT_MAX) {
 		error_reason("Not enough room for ECKD stage 2 loader "
 			     "(try larger block size)");
 		return -1;
 	}
-	for (i=0; i < stage2_count; i++) {
-		stage1->ssrt[i].read.count 	= stage2_list[i].chs.size;
-		stage1->seek[i].cyl		= stage2_list[i].chs.cyl;
-		stage1->seek[i].head		= stage2_list[i].chs.head |
+	for (i = 0; i < stage2_count; i++) {
+		stage1b->ssrt[i].read.count = stage2_list[i].chs.size;
+		stage1b->seek[i].cyl = stage2_list[i].chs.cyl;
+		stage1b->seek[i].head = stage2_list[i].chs.head |
 			((stage2_list[i].chs.cyl >> 12) & 0xfff0);
-		stage1->seek[i].sec		= stage2_list[i].chs.sec;
-		stage1->ssrt[i].read.address_lo	= ZIPL_STAGE2_LOAD_ADDRESS +
-						  i * stage2_list[i].chs.size;
-		stage1->ssrt[i].read.flags	= ECKD_CCW_FLAG_CC |
-						  ECKD_CCW_FLAG_SLI;
+		stage1b->seek[i].sec = stage2_list[i].chs.sec;
+		stage1b->ssrt[i].read.address_lo = ZIPL_STAGE2_LOAD_ADDRESS +
+			i * stage2_list[i].chs.size;
+		stage1b->ssrt[i].read.flags = CCW_FLAG_CC | CCW_FLAG_SLI;
 	}
 	/* Terminate CCW chain */
-	stage1->ssrt[i - 1].read.flags &= ~ECKD_CCW_FLAG_CC;
+	stage1b->ssrt[i - 1].read.flags &= ~CCW_FLAG_CC;
 	return 0;
 }
 
-
-int
-boot_init_eckd_classic_dump_stage1(struct boot_eckd_classic_stage1* stage1,
-				   struct disk_info* info)
-{
-	blocknum_t blocks;
-	blocknum_t i;
-
-	memcpy(stage1, DATA_ADDR(eckd1a),
-	       sizeof(struct boot_eckd_classic_stage1));
-	blocks = (DATA_SIZE(eckd2dump) +
-			info->phy_block_size - 1) / info->phy_block_size;
-	if (blocks > 8) {
-		error_reason("Not enough room for ECKD stage 2 dump record "
-			     "(try larger block size)");
-		return -1;
-	}
-	/* Fill in block list of stage 2 dump record */
-	for (i=0; i < blocks; i++) {
-		int cyl;
-
-		stage1->ssrt[i].read.count = info->phy_block_size;
-		stage1->ssrt[i].read.address_lo = ZIPL_STAGE2_LOAD_ADDRESS +
-						  i * info->phy_block_size;
-		cyl = disk_cyl_from_blocknum(i + info->geo.start, info);
-		stage1->seek[i].cyl = cyl;
-		stage1->seek[i].head =
-			disk_head_from_blocknum(i + info->geo.start, info) |
-			((cyl >> 12) & 0xfff0);
-		stage1->seek[i].sec =
-			disk_sec_from_blocknum(i + info->geo.start, info);
-	}
-	/* Terminate CCW chain */
-	stage1->ssrt[i - 1].read.flags &= ~ECKD_CCW_FLAG_CC;
-	return 0;
-}
-
-
-int
-boot_init_eckd_compatible_stage1(struct boot_eckd_compatible_stage1* stage1,
-				 struct disk_info* info)
-{
-	blocknum_t blocks;
-	blocknum_t i;
-
-	memcpy(stage1, DATA_ADDR(eckd1b),
-	       sizeof(struct boot_eckd_compatible_stage1));
-	/* Fill in blocklist for stage 2 loader */
-	blocks = (STAGE2_MAX_SIZE + info->phy_block_size - 1) /
-		 info->phy_block_size;
-	if (blocks > 12) {
-		error_reason("Not enough room for ECKD stage 2 loader "
-			     "(try larger block size)");
-		return -1;
-	}
-	for (i=0; i < blocks; i++) {
-		stage1->read[i].count		= info->phy_block_size;
-		stage1->read[i].address_lo	= ZIPL_STAGE2_LOAD_ADDRESS +
-						  i * info->phy_block_size;
-	}
-	/* Terminate CCW chain */
-	stage1->read[i - 1].flags &= ~ECKD_CCW_FLAG_CC;
-	return 0;
-}
-
-
 int
 boot_get_tape_ipl(void** data, size_t* size, address_t parm_addr,
 		  address_t initrd_addr, address_t image_addr)
@@ -267,85 +258,6 @@ boot_get_tape_ipl(void** data, size_t* size, address_t parm_addr,
 	return 0;
 }
 
-
-int
-boot_init_eckd_compatible_dump_stage1(
-				struct boot_eckd_compatible_stage1* stage1,
-				struct disk_info* info,
-				int mvdump_switch)
-{
-	blocknum_t blocks;
-	blocknum_t i;
-
-	memcpy(stage1, DATA_ADDR(eckd1b),
-	       sizeof(struct boot_eckd_compatible_stage1));
-	if (mvdump_switch)
-		blocks = (DATA_SIZE(eckd2mvdump) +
-			  info->phy_block_size - 1) / info->phy_block_size;
-	else
-		blocks = (DATA_SIZE(eckd2dump) +
-			  info->phy_block_size - 1) / info->phy_block_size;
-	if (blocks > 12) {
-		error_reason("Not enough room for ECKD stage 2 dump record "
-			     "(try larger block size)");
-		return -1;
-	}
-	/* Fill in block list of stage 2 dump record */
-	for (i = 0; i < blocks; i++) {
-		stage1->read[i].count = info->phy_block_size;
-		stage1->read[i].address_lo = ZIPL_STAGE2_LOAD_ADDRESS +
-					     i * info->phy_block_size;
-	}
-	/* Terminate CCW chain */
-	stage1->read[i - 1].flags &= ~ECKD_CCW_FLAG_CC;
-	return 0;
-}
-
-
-/* ASCII to EBCDIC conversion table. */
-unsigned char ascebc[256] =
-{
-     0x00, 0x01, 0x02, 0x03, 0x37, 0x2D, 0x2E, 0x2F,
-     0x16, 0x05, 0x15, 0x0B, 0x0C, 0x0D, 0x0E, 0x0F,
-     0x10, 0x11, 0x12, 0x13, 0x3C, 0x3D, 0x32, 0x26,
-     0x18, 0x19, 0x3F, 0x27, 0x22, 0x1D, 0x1E, 0x1F,
-     0x40, 0x5A, 0x7F, 0x7B, 0x5B, 0x6C, 0x50, 0x7D,
-     0x4D, 0x5D, 0x5C, 0x4E, 0x6B, 0x60, 0x4B, 0x61,
-     0xF0, 0xF1, 0xF2, 0xF3, 0xF4, 0xF5, 0xF6, 0xF7,
-     0xF8, 0xF9, 0x7A, 0x5E, 0x4C, 0x7E, 0x6E, 0x6F,
-     0x7C, 0xC1, 0xC2, 0xC3, 0xC4, 0xC5, 0xC6, 0xC7,
-     0xC8, 0xC9, 0xD1, 0xD2, 0xD3, 0xD4, 0xD5, 0xD6,
-     0xD7, 0xD8, 0xD9, 0xE2, 0xE3, 0xE4, 0xE5, 0xE6,
-     0xE7, 0xE8, 0xE9, 0xBA, 0xE0, 0xBB, 0xB0, 0x6D,
-     0x79, 0x81, 0x82, 0x83, 0x84, 0x85, 0x86, 0x87,
-     0x88, 0x89, 0x91, 0x92, 0x93, 0x94, 0x95, 0x96,
-     0x97, 0x98, 0x99, 0xA2, 0xA3, 0xA4, 0xA5, 0xA6,
-     0xA7, 0xA8, 0xA9, 0xC0, 0x4F, 0xD0, 0xA1, 0x07,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x59, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F,
-     0x90, 0x3F, 0x3F, 0x3F, 0x3F, 0xEA, 0x3F, 0xFF
-};
-
-static void ascii_to_ebcdic(unsigned char* from, unsigned char* to)
-{
-	for (;from != to; from++)
-		*from = ascebc[*from];
-}
-
-
 struct menu_buffer {
 	void *start;
 	size_t size;
@@ -391,7 +303,8 @@ mb_sprintf(struct menu_buffer *buffer, const char *fmt, ...)
 	va_end(args);
 	if (len < 0 || len >= size)
 		return NULL;
-	ascii_to_ebcdic((unsigned char *) str, (unsigned char *) str + len);
+	misc_ascii_to_ebcdic((unsigned char *) str,
+			     (unsigned char *) str + len);
 	mb_alloc(buffer, len + 1);
 
 	return str;
@@ -408,14 +321,25 @@ store_stage2_menu(void* data, size_t size, struct job_data* job)
 	int i;
 	struct menu_buffer mb;
 	void *str;
+	uint64_t config_kdump = 0;
 
 	mb_init(&mb, data, size);
 	if (job->id == job_menu) {
 		name = "-";
-		for (i=0; i < job->data.menu.num; i++)
+		for (i = 0; i < job->data.menu.num; i++) {
+			if (job->data.menu.entry[i].id == job_ipl &&
+			    job->data.menu.entry[i].data.ipl.is_kdump)
+				/* we start with 2nd bit */
+				config_kdump |= (0x1 << (i + 1));
 			if (job->data.menu.entry[i].pos ==
-			    job->data.menu.default_pos)
+			    job->data.menu.default_pos) {
+				if (job->data.menu.entry[i].id == job_ipl &&
+				    job->data.menu.entry[i].data.ipl.is_kdump)
+					/* default entry is first bit */
+					config_kdump |= 0x1;
 				name = job->data.menu.entry[i].name;
+			}
+		}
 		flag = (job->data.menu.prompt != 0);
 		timeout = job->data.menu.timeout;
 		/* Be verbose */
@@ -432,6 +356,8 @@ store_stage2_menu(void* data, size_t size, struct job_data* job)
 			printf("  Default configuration...: '%s'\n", name);
 		}
 	} else {
+		if (job->id == job_ipl && job->data.ipl.is_kdump)
+			config_kdump |= 0x1;
 		name = job->name;
 		flag = 0;
 		timeout = 0;
@@ -441,6 +367,7 @@ store_stage2_menu(void* data, size_t size, struct job_data* job)
 	if (!params)
 		goto err_nospace;
 	params->flag = flag;
+	params->config_kdump = config_kdump;
 	params->timeout = timeout;
 	/* Banner text */
 	str = mb_sprintf(&mb, "zIPL v%s interactive boot menu\n ",
@@ -463,8 +390,13 @@ store_stage2_menu(void* data, size_t size, struct job_data* job)
 		return 0;
 	/* Config texts */
 	for (i = 0; i < job->data.menu.num; i++) {
-		str = mb_sprintf(&mb, "%2d. %s", job->data.menu.entry[i].pos,
-						 job->data.menu.entry[i].name);
+		const char *kdump_str = "";
+		if (job->data.menu.entry[i].data.ipl.is_kdump)
+			kdump_str = " (kdump)";
+		str = mb_sprintf(&mb, "%2d. %s%s",
+				 job->data.menu.entry[i].pos,
+				 job->data.menu.entry[i].name,
+				 kdump_str);
 		if (!str)
 			goto err_nospace_user;
 		params->config[job->data.menu.entry[i].pos] = (uint16_t)
@@ -534,15 +466,15 @@ boot_get_tape_dump(void** data, size_t* size, uint64_t mem)
 {
 	void* buffer;
 
-	buffer = misc_malloc(DATA_SIZE(tapedump));
+	buffer = misc_malloc(DATA_SIZE(tape2dump));
 	if (buffer == NULL)
 		return -1;
-	memcpy(buffer, DATA_ADDR(tapedump), DATA_SIZE(tapedump));
+	memcpy(buffer, DATA_ADDR(tape2dump), DATA_SIZE(tape2dump));
 	/* Write mem size to end of dump record */
-	memcpy(VOID_ADD(buffer, DATA_SIZE(tapedump) - sizeof(mem)), &mem,
+	memcpy(VOID_ADD(buffer, DATA_SIZE(tape2dump) - sizeof(mem)), &mem,
 	       sizeof(mem));
 	*data = buffer;
-	*size = DATA_SIZE(tapedump);
+	*size = DATA_SIZE(tape2dump);
 	return 0;
 }
 
@@ -552,15 +484,15 @@ boot_get_eckd_dump_stage2(void** data, size_t* size, uint64_t mem)
 {
 	void* buffer;
 
-	buffer = misc_malloc(DATA_SIZE(eckd2dump));
+	buffer = misc_malloc(DATA_SIZE(eckd2dump_sv));
 	if (buffer == NULL)
 		return -1;
-	memcpy(buffer, DATA_ADDR(eckd2dump), DATA_SIZE(eckd2dump));
+	memcpy(buffer, DATA_ADDR(eckd2dump_sv), DATA_SIZE(eckd2dump_sv));
 	/* Write mem size to end of dump record */
-	memcpy(VOID_ADD(buffer, DATA_SIZE(eckd2dump) - sizeof(mem)),
+	memcpy(VOID_ADD(buffer, DATA_SIZE(eckd2dump_sv) - sizeof(mem)),
 	       &mem, sizeof(mem));
 	*data = buffer;
-	*size = DATA_SIZE(eckd2dump);
+	*size = DATA_SIZE(eckd2dump_sv);
 	return 0;
 }
 
@@ -570,22 +502,22 @@ boot_get_eckd_mvdump_stage2(void** data, size_t* size, uint64_t mem,
 {
 	void* buffer;
 
-	buffer = misc_malloc(DATA_SIZE(eckd2mvdump));
+	buffer = misc_malloc(DATA_SIZE(eckd2dump_mv));
 	if (buffer == NULL)
 		return -1;
-	memcpy(buffer, DATA_ADDR(eckd2mvdump), DATA_SIZE(eckd2mvdump));
+	memcpy(buffer, DATA_ADDR(eckd2dump_mv), DATA_SIZE(eckd2dump_mv));
 	/* Write mem size and force indicator (as specified by zipl -M)
 	 * to end of dump record, right before 512-byte parameter table */
-	memcpy(VOID_ADD(buffer, DATA_SIZE(eckd2mvdump) - sizeof(mem) -
+	memcpy(VOID_ADD(buffer, DATA_SIZE(eckd2dump_mv) - sizeof(mem) -
 			sizeof(struct mvdump_parm_table)), &mem, sizeof(mem));
-	memcpy(VOID_ADD(buffer, DATA_SIZE(eckd2mvdump) - sizeof(mem) -
+	memcpy(VOID_ADD(buffer, DATA_SIZE(eckd2dump_mv) - sizeof(mem) -
 			sizeof(force) - sizeof(struct mvdump_parm_table)),
 	       &force, sizeof(force));
-	memcpy(VOID_ADD(buffer, DATA_SIZE(eckd2mvdump) -
+	memcpy(VOID_ADD(buffer, DATA_SIZE(eckd2dump_mv) -
 			sizeof(struct mvdump_parm_table)), &parm,
 	       sizeof(struct mvdump_parm_table));
 	*data = buffer;
-	*size = DATA_SIZE(eckd2mvdump);
+	*size = DATA_SIZE(eckd2dump_mv);
 	return 0;
 }
 
@@ -606,3 +538,30 @@ boot_get_fba_dump_stage2(void** data, size_t* size, uint64_t mem)
 	*size = DATA_SIZE(fba2dump);
 	return 0;
 }
+
+void
+boot_get_dump_info(struct boot_info *boot_info, uint8_t dev_type, void *param)
+{
+	memset(boot_info, 0, sizeof(*boot_info));
+	memcpy(&boot_info->magic, BOOT_INFO_MAGIC, sizeof(boot_info->magic));
+	boot_info->flags |= BOOT_INFO_FLAGS_ARCH;
+	boot_info->dev_type = dev_type;
+	boot_info->bp_type = BOOT_INFO_BP_TYPE_DUMP;
+	boot_info->version = BOOT_INFO_VERSION;
+	memcpy(&boot_info->bp.dump.param, param,
+	       sizeof(boot_info->bp.dump.param));
+}
+
+void
+boot_get_ipl_info(struct boot_info *boot_info, uint8_t dev_type,
+		  disk_blockptr_t *bm_ptr, struct disk_info *info)
+{
+	memset(boot_info, 0, sizeof(*boot_info));
+	memcpy(&boot_info->magic, BOOT_INFO_MAGIC, sizeof(boot_info->magic));
+	boot_info->flags |= BOOT_INFO_FLAGS_ARCH;
+	boot_info->dev_type = dev_type;
+	boot_info->bp_type = BOOT_INFO_BP_TYPE_IPL;
+	boot_info->version = BOOT_INFO_VERSION;
+	bootmap_store_blockptr(&boot_info->bp, bm_ptr, info);
+}
+
