@@ -170,12 +170,6 @@ determine_virtblk_type(struct disk_info *data, struct stat *stats)
 		}
 		close(fd);
 		misc_free_temp_dev(device);
-	} else if (data->geo.heads == 16) {
-		error_text("Assume disk_type FBA for virtblk device, "
-			   "but please specify type manually");
-		data->geo.start >>= shift;
-		disk_print_geo(data);
-		rc = -1;
 	} else {
 		data->type = disk_type_scsi;
 		data->partnum = stats->st_rdev & SCSI_PARTN_MASK;
@@ -200,7 +194,7 @@ disk_get_info(const char* device, struct job_target_data* target,
 	int fd;
 	long devsize;
 	FILE *fh;
-	char *script_pre = "/lib/s390-tools/zipl_helper.";
+	char *script_pre = TOOLS_LIBDIR "/zipl_helper.";
 	char script_file[80];
 	char ppn_cmd[80];
 	char buffer[80];
