@@ -33,45 +33,45 @@ enum scan_key_state scan_key_table[SCAN_SECTION_NUM][SCAN_KEYWORD_NUM] = {
  *	 ult  to   tofs e    mete file isk  ent  et   pt   out  ultm      dump
  *			     rs                                 enu
  *
- *       targ targ targ targ targ defa
- *       etba etty etge etbl etof ulta
+ *       targ targ targ targ targ defa kdum
+ *       etba etty etge etbl etof ulta p
  *       se   pe   omet ocks fset uto
  *                 ry   ize
  */
 /* default auto */
 	{opt, inv, inv, inv, inv, inv, inv, inv, req, opt, opt, inv, inv, inv,
-	 opt, opt, opt, opt, opt, opt},
+	 opt, opt, opt, opt, opt, opt, inv},
 /* default menu */
 	{inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, req, inv, inv,
-	 inv, inv, inv, inv, inv, inv},
+	 inv, inv, inv, inv, inv, inv, inv},
 /* default section */
 	{req, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv,
-	 inv, inv, inv, inv, inv, inv},
+	 inv, inv, inv, inv, inv, inv, inv},
 /* ipl		*/
 	{inv, inv, inv, req, opt, opt, opt, inv, req, inv, inv, inv, inv, inv,
-	 opt, opt, opt, opt, opt, inv},
+	 opt, opt, opt, opt, opt, inv, opt},
 /* segment load */
 	{inv, inv, inv, inv, inv, inv, inv, req, req, inv, inv, inv, inv, inv,
-	 inv, inv, inv, inv, inv, inv},
+	 inv, inv, inv, inv, inv, inv, inv},
 /* part dump	*/
 	{inv, req, inv, inv, inv, inv, inv, inv, opt, inv, inv, inv, inv, inv,
-	 inv, inv, inv, inv, inv, inv},
+	 inv, inv, inv, inv, inv, inv, inv},
 /* fs dump	*/
 	{inv, inv, req, inv, opt, opt, inv, inv, req, inv, inv, inv, inv, inv,
-	 inv, inv, inv, inv, inv, inv},
+	 inv, inv, inv, inv, inv, inv, inv},
 /* ipl tape	*/
 	{inv, inv, inv, req, opt, opt, opt, inv, inv, inv, inv, inv, req, inv,
-	 inv, inv, inv, inv, inv, inv},
+	 inv, inv, inv, inv, inv, inv, inv},
 /* multi volume dump	*/
 	{inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, req,
-	 inv, inv, inv, inv, inv, inv}
+	 inv, inv, inv, inv, inv, inv, inv}
 };
 
 /* Determines which keyword may be present in a menu section */
 enum scan_key_state scan_menu_key_table[SCAN_KEYWORD_NUM] = {
 /* menu section */
 	 opt, inv, inv, inv, inv, inv, inv, inv, req, opt, opt, inv, inv, inv,
-	 opt, opt, opt, opt, opt, inv
+	 opt, opt, opt, opt, opt, inv, inv
 };
 
 /* Mapping of keyword IDs to strings */
@@ -97,7 +97,8 @@ static const struct {
 	{ "target", scan_keyword_target},
 	{ "prompt", scan_keyword_prompt},
 	{ "timeout", scan_keyword_timeout},
-	{ "tape", scan_keyword_tape}
+	{ "tape", scan_keyword_tape},
+	{ "kdump", scan_keyword_kdump},
 };
 
 /* List of keywords that are used without an assignment */
@@ -701,8 +702,6 @@ scan_get_target_type(char *type)
 	return target_type_invalid;
 }
 
-#define MAX(a,b)	((a)>(b)?(a):(b))
-
 /* Check section data for correctness. KEYWORD[keyword_id] defines whether
  * a keyword is present, LINE[keyword_id] specifies in which line a keyword
  * was found or NULL when specified on command line, NAME specifies the
@@ -730,8 +729,9 @@ scan_check_section_data(char* keyword[], int* line, char* name,
 			*type = section_dump;
 			main_keyword = scan_keyword_name(scan_keyword_dumpto);
 		} else if (keyword[(int) scan_keyword_dumptofs]) {
-			*type = section_dumpfs;
-			main_keyword = scan_keyword_name(scan_keyword_dumptofs);
+			error_reason("Option dumptofs is deprecated, "
+				     "use dumpto instead");
+			return -1;
 		} else if (keyword[(int) scan_keyword_mvdump]) {
 			*type = section_mvdump;
 			main_keyword = scan_keyword_name(scan_keyword_mvdump);
@@ -1673,10 +1673,14 @@ scan_build_automenu(struct scan_token* scan)
 		if (scan[i].id == scan_id_section_heading)
 			num_sections++;
 	}
-	size = /* old scan array + delimiter */ i + 1 +
-	       /* defaultboot heading + keyword */ 2 +
-	       /* automenu heading + keywords */ 10 +
-	       /* missing target definitions */ num_sections * num_targets;
+	size = /* old scan array + delimiter */     i + 1 +
+	       /* defaultboot heading  */           1 +
+	       /* defaultmenu */                    1 +
+	       /* menu heading  */                  1 +
+	       /* keyword default,prompt,timeout */ 3 +
+	       /* target keywords*/                 num_targets +
+	       /* missing target definitions */     num_sections * num_targets +
+	       /* number assigment  */              num_sections;
 	size *= sizeof(struct scan_token);
 	new_scan = misc_malloc(size);
 	if (!new_scan)
